import QtQuick 1.1
import com.nokia.meego 1.0
import "Const.js" as Const
import "RunMemory.js" as MemoryUtil

Flickable{
    id: root

    property string title
    property string author
    property string date
    property string body
    property bool hasNext
    property string link

    signal linked
    signal clicked

    flickableDirection: Flickable.VerticalFlick
//    anchors.fill: parent
    contentWidth: Math.max(parent.width,content.width)
    contentHeight: Math.max(parent.height,content.height)

    pressDelay: 200

    visible: false

    onContentHeightChanged: {
        contentWidth = Math.max(parent.height,content.height);
        contentWidth: Math.max(parent.width,content.width)
    }

    Item{
        id: content
        width: content_area.width; height: article_page.hasNext ? title_rect.height + content_rect.height + next_btn.height : title_rect.height + content_rect.height

        Rectangle{
            id: title_rect
            width: content_area.width; height: 100
            color: Const.Color.rectTrans
            border{width: 1; color: "#DFDFDF"}

            Column{
                anchors.fill: parent

                Rectangle{
                    width: title_rect.width; height: 60
                    color: Const.Color.rectTrans
                    Text{
                        id: title
                        text: root.title
                        width: parent.width - 20; height: parent.height - 30
                        anchors.centerIn: parent
                        font{pointSize: 20; bold: true}
                        color: "#363636"

                        elide: Text.ElideRight

                        horizontalAlignment: Text.AlignHCenter
                        verticalAlignment: Text.AlignVCenter

                    }
                }

                Rectangle{
                    width: title_rect.width; height: 40
                    color: Const.Color.rectTrans

                    Text{
                        id: comment
                        width: parent.width - 15; height: parent.height - 10
                        anchors.centerIn: parent
                        text: root.date+"  来源:"+root.author
                        color: "#525456"
                        font{pointSize: 15}

                        elide: Text.ElideRight

                        horizontalAlignment: Text.AlignHCenter
                        verticalAlignment: Text.AlignVCenter


                    }
                }

            }



        }

        Item{
            id: content_rect
            width: content_area.width; height: content_text.height + 20
            anchors{left: parent.left; top: title_rect.bottom}

            Text{
            id: content_text
            font{pointSize: MemoryUtil.CurrentSize}
            width: parent.width - 30
            anchors.centerIn: parent
            text: root.body

            wrapMode: Text.WordWrap
            color: Const.Color.article

            lineHeightMode: Text.FixedHeight
            lineHeight: 40

            onLinkActivated: {
                root.link = link;
                root.linked();
//                article_page.begin();
//                console.log("link:"+link);
//                openBigImage(link);
//                article_page.finish();
            }
            }
        }

        Item{
            id: next_btn
            width: parent.width; height: 100
            anchors{left: parent.left; top: content_rect.bottom}
            Rectangle{
                id: content_footer
                visible: root.hasNext;
                width: parent.width - 40; height: parent.height - 20
                anchors.centerIn: parent
                color: Const.Color.rectTrans
        Row{
            anchors.fill: parent
            Image{
                id: left_img
                width: 7; height: parent.height
                source: "images/button1_left.png"
            }

            Image {
                id: middle_img
                width: parent.width - left_img.width - right_img.width; height: parent.height
                source: "images/button1_mid.png"

            }
            Image{
                id: right_img
                width: 7; height: parent.height
                source: "images/button1_right.png"
            }
        }

                Text{
                    color: "#464646"
                    font{pointSize: Const.FontSize.menuSize}
                    width: parent.width - 20; height: parent.height - 10
                    anchors.centerIn: parent

                    horizontalAlignment: Text.AlignHCenter
                    verticalAlignment: Text.AlignVCenter

                    text: "查看全文"
                }

                PressArea{
                    anchors.fill: parent
                    pressRadius: 10

                    onClicked: {
                        root.clicked();
                    }
                }
            }

        }
    }

    function appendBody(body){
        var content = root.body + body;
        root.body = content;
    }
}

