import QtQuick 1.1
import com.nokia.meego 1.0
import "Const.js" as Const
import "Common.js" as Common
import "Component"
import "RunMemory.js" as MemoryUtil
import "Database.js" as DBUtil

CustomPage {
    id: article_page

    tools: toolbar

    NomalToolbar{
        id: toolbar

        isFavorited: article_page.isFavorite
        favoriteVisible: false
        onReplyed: {
            reply_comment.open();
        }

        onFavorited: {
            if(article_page.isFavorite){
                fav_dialog.open("您确定要取消该收藏吗?")
            }else{
                DBUtil.addArticleFavorite(article_page.docId, article_page.title);
                article_page.isFavorite = true;
                article_page.showInfo("文章收藏成功");
            }
        }
    }

    ConfirmDialog{
        id: fav_dialog
        onAccepted: {
            DBUtil.removeSingleFavorite(article_page.docId, Const.FavorateType.Article);
            article_page.isFavorite = false;
            article_page.showInfo("文章收藏已经取消");
        }
    }

    property int replyCount : 0

    property string docId
    property string tid: ""
    property int pageIndex: -1
    property string title
    property string date
    property string author
    property string body
    property string replyBoard

    property bool hasNext: false

    property string commentType: Const.Comment.Today
    property string currentP

    property string articleScope: Const.ArticleScope.Head

    property bool isFavorite: DBUtil.isFavoriteExists(article_page.docId, Const.FavorateType.Article)

    TopBackGround{
        id: top_bar
        anchors{left: parent.left; top: parent.top}
        name: "新闻"

        onClicked: {
            article_page.positionViewAtBeginning();
        }

        BackButton{
            width: parent.height; height: parent.height
            anchors{left: parent.left; top: parent.top}
        }

        Rectangle{
            width: 120; height: parent.height
            color: Const.Color.rectTrans
            anchors{right: parent.right}

            CommentButton{
                width: 110; height: 55
                anchors.centerIn: parent

                name: article_page.replyCount + "跟帖"
                //                textBold: false

                onClicked: {
                    console.log("jump to comment page");
                    pageStack.replace(Qt.resolvedUrl("CommentPage.qml"),{
                                          articleTId:article_page.tid,
                                          picIndex: article_page.pageIndex,
                                          docId:article_page.docId,
                                          replyBoard:article_page.replyBoard,
                                          title: article_page.title,
                                          commentType: article_page.commentType,
                                          currentP: article_page.currentP});
                }
            }
        }
    }

    ListModel{
        id: listModel
    }

    Rectangle{
        id: content_area
        width: parent.width; height: parent.height - top_bar.height
        anchors{left:parent.left; top: top_bar.bottom}
        //        color: Const.Color.background
        gradient: Gradient {
            GradientStop { position: 0.0; color: Const.Color.backgroundTop }
            GradientStop { position: 1; color: Const.Color.backgroundBottom }
        }

        ReloadBackground{
            id: reload_back
            anchors.fill: parent
            visible: false
        }

        Flickable{
            id: flick_item
            flickableDirection: Flickable.VerticalFlick
            anchors.fill: parent
            contentWidth: Math.max(parent.width,content.width)
            contentHeight: Math.max(parent.height,content.height)

            pressDelay: 200
            Item{
                id: content
                width: content_area.width; height: article_page.hasNext ? title_rect.height + content_rect.height + next_btn.height : title_rect.height + content_rect.height

                Rectangle{
                    id: title_rect
                    width: content_area.width; height: 100
                    color: Const.Color.rectTrans

                    Column{
                        anchors.fill: parent

                        Rectangle{
                            width: title_rect.width; height: 60
                            color: Const.Color.rectTrans
                            Text{
                                id: title
                                text: article_page.title
                                width: parent.width - 20; height: parent.height - 30
                                anchors.centerIn: parent
                                font{pointSize: 19; bold: true}
                                color: "#262626"

                                elide: Text.ElideRight

                                horizontalAlignment: Text.AlignHCenter
                                verticalAlignment: Text.AlignVCenter

                            }
                        }

                        Rectangle{
                            width: title_rect.width; height: 40
                            color: Const.Color.rectTrans

                            Text{
                                id: comment
                                width: parent.width - 15; height: parent.height - 10
                                anchors.centerIn: parent
                                text: article_page.date+"  来源:"+article_page.author
                                color: "#787676"
                                font{pointSize: 16}

                                elide: Text.ElideRight

                                horizontalAlignment: Text.AlignHCenter
                                verticalAlignment: Text.AlignVCenter


                            }
                        }

                    }

                    Image{
                        id: line
                        source: "images/line.png"
                        anchors{left: parent.left; bottom: parent.bottom}
                        width: parent.width
                    }

                }

                Item{
                    id: content_rect
                    width: content_area.width; height: content_col.height + 20
                    anchors{left: parent.left; top: title_rect.bottom}

                    Column{
                        id: content_col
                        Repeater{
                            model: listModel
                            delegate: Item{
                                width: content_rect.width; height: content_text.height
                                Text{
                                    id: content_text
                                    font{pointSize: MemoryUtil.CurrentSize}
                                    width: parent.width - 30
                                    anchors.horizontalCenter: parent.horizontalCenter
                                    text: articleContent

                                    wrapMode: Text.WordWrap
                                    color: Const.Color.article

                                    lineHeightMode: Text.FixedHeight
                                    smooth: true
                                    lineHeight: 40

                                    onLinkActivated: {
                                        article_page.begin();
                                        console.log("link:"+link);
                                        openBigImage(link);
                                        article_page.finish();
                                    }

                                }
                            }
                        }
                    }

                }

                Item{
                    id: next_btn
                    width: parent.width; height: 80
                    visible: article_page.hasNext
                    anchors{left: parent.left; top: content_rect.bottom}
                    Rectangle{
                        id: content_footer
                        visible: article_page.hasNext;
                        width: parent.width * 3 / 4; height: parent.height - 20
                        anchors.centerIn: parent

                        color: Const.Color.rectTrans
                        Row{
                            anchors.fill: parent
                            Image{
                                id: left_img
                                width: 7; height: parent.height
                                source: "images/button1_left.png"
                            }

                            Image {
                                id: middle_img
                                width: parent.width - left_img.width - right_img.width; height: parent.height
                                source: "images/button1_mid.png"

                            }
                            Image{
                                id: right_img
                                width: 7; height: parent.height
                                source: "images/button1_right.png"
                            }
                        }

                        Text{
                            color: "#464646"
                            font{pointSize: Const.FontSize.menuSize}
                            width: parent.width - 20; height: parent.height - 10
                            anchors.centerIn: parent

                            horizontalAlignment: Text.AlignHCenter
                            verticalAlignment: Text.AlignVCenter

                            text: "查看全文"
                        }

                        PressArea{
                            anchors.fill: parent
                            pressRadius: 10

                            onClicked: {
                                article_page.fullContent();
                            }
                        }
                    }

                }
            }
        }

        ScrollDecorator{
            flickableItem: flick_item
            platformStyle: ScrollDecoratorStyle{inverted: false}
        }

    }


    Item{
        id: img_big_rect
        anchors.fill: parent
        visible: false
        z: Number.MAX_VALUE

        MouseArea{
            anchors.fill: parent

            onClicked: {
                closeBigImage();
            }
        }

        Rectangle{
            color: "black"
            anchors.fill: parent
            opacity: 0.5
        }

        Rectangle{
            id: big_img
            color: "black"
            width: parent.width - 80; height: img_src.height + img_alt.height + 10
            anchors.centerIn: parent

            border{width: 2; color: "#DDDDDD"}

            Image{
                id: img_src
                fillMode: Image.PreserveAspectFit
                width: parent.width - 10
                anchors{left: parent.left; leftMargin: 5; top: parent.top; topMargin: 10}

            }

            Text{
                id: img_alt
                width: parent.width - 100; height: 80
                anchors{left: parent.left; bottom: parent.bottom}
                horizontalAlignment: Text.AlignLeft
                verticalAlignment: Text.AlignVCenter

                elide: Text.ElideRight
                font{pointSize: 18}
                color: "white"
            }

            Item{
                id: save_item
                width: 80; height: 80
                anchors{right: parent.right; rightMargin: 20; bottom: parent.bottom}
                Image{
                    anchors.centerIn: parent
                    source: "images/toolbar_save.png"
                }

                PressArea{
                    anchors.fill: parent

                    onClicked: {
                        console.debug("down the pic:"+img_src.source);
                        imageDownload.download(img_src);
                        article_page.showInfo("图片下载成功");
                    }
                }
            }
        }
    }

    ImageDownload{
        id: imageDownload
    }

    Rectangle{
        id: left_pager
        color: Const.Color.rectTrans
        width: 50; height: 520
        anchors{left: parent.left; verticalCenter: parent.verticalCenter}
        z: 80
        visible: true
        Image{
            id: left_pager_img
            source: "images/contentview_left_pager.png"
            anchors.fill: parent
            visible: false
        }

        MouseArea{
            id: left_pager_area
            anchors.fill: parent

            onClicked: {
                prePage();
            }
        }

        states: [
            State {
                name: 'pressed'; when: left_pager_area.pressed
                PropertyChanges { target: left_pager_img; focus: true; visible: true}
            }
        ]
    }

    Rectangle{
        id: right_pager
        color: Const.Color.rectTrans
        width: 50; height: 520
        anchors{right: parent.right; verticalCenter: parent.verticalCenter}
        z: 80
        visible: true
        Image{
            id: right_pager_img
            source: "images/contentview_right_pager.png"
            anchors.fill: parent
            visible: false
        }
        MouseArea{
            id: right_pager_area
            anchors.fill: parent

            onClicked: {
                nextPage();
            }
        }

        states: [
            State {
                name: 'pressed'; when: right_pager_area.pressed
                PropertyChanges { target: right_pager_img; focus: true; visible: true}
            }
        ]
    }

    BusyLoading{
        id: loading
        anchors.centerIn: parent
    }

    InfoShow{
        id: infoShow
        anchors{bottom: parent.bottom; bottomMargin: 50}
    }

    ReplyToolbar{
        id: reply_comment

        anchors.fill: parent

        onSumbited: {
            console.debug("reply submit");
            replyComment();
        }

        onClosed: {
            toolbar.showImg();
        }

        visible: article_page.toolsStatus === Const.Status.Opened
    }


    HostInfo{
        id: hostinfo
    }

    onLoaded: {
        isPager();
        getArticle();
    }

    function getArticle(){
        reload_back.visible = true;
        toolbar.favoriteVisible = false;
        Common.getStringByUrl("GET","http://c.3g.163.com/nokia/nc/article/"+article_page.docId+"/"+article_page.articleScope+".html", articleCallback);
    }

    function getReplyCount(){
        Common.getStringByUrl("GET","http://c.3g.163.com/nokia/nc/article/"+article_page.docId+"/"+article_page.articleScope+".html", replyCallback);
    }

    function replyCallback(responseText){
        var obj = JSON.parse(responseText);
        article_page.replyCount = content.replyCount;
    }

    function articleCallback(responseText){
        article_page.connectioned();
        listModel.clear();
        var obj = JSON.parse(responseText);
        //        for(var i in obj){
        var content = obj[article_page.docId];
        article_page.docId = content.docid;
        article_page.author = content.source;
        var articleBody = content.body.replace(new RegExp("<p>　　","gm"),"    ");
        articleBody = articleBody.replace(new RegExp("<\/p>","gm"),"<br\/>").replace(new RegExp("<!--(?!IMG)(.)*-->","gm"),"")
        article_page.date = content.ptime;
        article_page.title = content.title;
        article_page.replyCount = content.replyCount;
        article_page.replyBoard = content.replyBoard;
        var imgs = content.img;
        for(var k in imgs){
            var im = imgs[k];
            var autoImg = "http://s.cimg.163.com/i/"+im.src.replace(new RegExp("http://","gm"),"")+"."+(content_rect.width / 2 + 10) +"x"+(content_rect.width / 2) +".auto.jpg";
            articleBody = articleBody.replace(new RegExp(im.ref,"gm"), "<a href=\""+im.src+"#"+im.alt+"\" ><img width=\""+(content_rect.width / 2 + 10)+"\" height=\""+(content_rect.width / 2 )+"\" src="+autoImg+" align =\"right\" \/><\/a>");
        }

        if(content.hasNext){
            content_footer.visible = true;
        }else{
            articleBody += " (完)";
        }
        var cs = articleBody.split("<br\/>");
        for(var c in cs){
            var ac = cs[c];
            listModel.append({
                                 "articleContent":ac
                             });
        }

        //            content_text.text = articleBody;
        toolbar.favoriteVisible = true;
        article_page.isFavorite = DBUtil.isFavoriteExists(article_page.docId, Const.FavorateType.Article);
        article_page.hasNext = content.hasNext;
        //        }
        positionViewAtBeginning();
        //        if(MemoryUtil.IsPager && article_page.pageIndex >= 0){
        //            article_page.showInfo(" + (article_page.pageIndex + 1)+ ");
        //        }
        reload_back.visible = false;
        article_page.finish();
    }

    function prePage(){
        article_page.begin();
        reload_back.visible = true;
        console.log("go pre page");
        if(article_page.pageIndex === 0){
            article_page.showInfo("当前已经是第1篇文章");
            article_page.finish();
        }else{
            Common.getStringByUrl("GET", "http://c.3g.163.com/nokia/nc/article/list/"+article_page.tid+"/"+(article_page.pageIndex - 1)+"-1.html", newsCallback);
            article_page.pageIndex -= 1;
        }
    }

    function newsCallback(responseText){
        var obj = JSON.parse(responseText);

        for(var i in obj){
            createModelFromJson(obj[i]);
        }
    }

    function createModelFromJson(obj, tid){
        for(var i in obj){
            var c = obj[i];
            article_page.docId = c.docid;
            getArticle();
        }
    }
    function nextPage(){
        article_page.begin();
        reload_back.visible = false;
        console.log("go next page");
        Common.getStringByUrl("GET", "http://c.3g.163.com/nokia/nc/article/list/"+article_page.tid+"/"+(article_page.pageIndex + 1)+"-1.html", newsCallback);
        article_page.pageIndex += 1;

    }

    function isPager(){
        if(MemoryUtil.IsPager && article_page.pageIndex >= 0){
            left_pager.visible = true;
            right_pager.visible = true;
        }else{
            left_pager.visible = false;
            right_pager.visible = false;
        }
    }

    function openBigImage(link){
        var info = link.split("#");
        img_src.source = info[0];
        console.debug("img source:"+img_src.source);
        img_alt.text = info[1];
        save_item.visible = true;
        img_big_rect.visible = true;
    }

    function closeBigImage(){
        img_src.source = "";
        img_alt.text = "";
        save_item.visible = false;
        img_big_rect.visible = false;
    }

    function positionViewAtBeginning(){
        flick_item.contentY = 0;
    }

    function replyComment(){
        var account = DBUtil.getAccount();
        if(account.username === undefined || account.username === null || account.username === ""){
            article_page.showInfo("登录后才能跟贴");
            reply_comment.open();
            return;
        }
        if(reply_comment.text === ""){
            article_page.showInfo("请填写跟帖内容");
            reply_comment.open();
            return;
        }
        var params = "board="+article_page.replyBoard+"&threadid="+article_page.docId+"&body="+reply_comment.text+"&userid="+account.username+"&nickname="+account.nickname+"&ip="+hostinfo.getLocalIp()+"&hidename=false";
        console.debug("params:"+params);
        article_page.begin();
        reply_comment.close();
        var doc = new XMLHttpRequest();
        doc.onreadystatechange = function() {
                    if ((doc.readyState == 4) && (doc.status == 200)) {
                        article_page.connectioned();
                        console.debug(doc.responseText);
                        var obj = JSON.parse(doc.responseText);
                        article_page.finish();
                        if(obj.code === "1"){
                            reply_comment.initReply();
                            getReplyCount();
                            toolbar.showImg();
                            article_page.showInfo("您的帖子已经成功提交");
                        }else{
                            reply_comment.open();
                            if(obj.code === "-1"){
                                article_page.showInfo("参数为null");
                            }else if(obj.code === "-2"){
                                article_page.showInfo("版面不存在");
                            }else if(obj.code === "-3"){
                                article_page.showInfo("ThreadData数据错误");
                            }else if(obj.code === "-4"){
                                article_page.showInfo("PostData数据错误");
                            }else if(obj.code === "-5"){
                                article_page.showInfo("发贴间隔太短");
                            }else if(obj.code === "-6"){
                                article_page.showInfo("跟贴大楼封顶");
                            }else if(obj.code === "-7"){
                                article_page.showInfo("异步存储到跟贴个人页错误");
                            }else{
                                article_page.showInfo("跟帖失败");
                            }
                        }
                    }
                }
        doc.open("POST", "http://comment.api.163.com/api/jsonp/post/insert", true);
        doc.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
        doc.send(params);
    }

    function fullContent(){
        article_page.begin();
        Common.getStringByUrl("GET","http://c.3g.163.com/nokia/nc/article/"+article_page.docId+"/"+Const.ArticleScope.Tail+".html", fullCallback);
    }

    function fullCallback(responseText){
        article_page.connectioned();
        content_footer.visible = false;
        var obj = JSON.parse(responseText);
        for(var i in obj){
            var content = obj[i];
            article_page.docId = content.docid;
            article_page.author = content.source;
            var articleBody = content.body.replace(new RegExp("<p>　　","gm"),"    ");
            articleBody = articleBody.replace(new RegExp("<\/p>","gm"),"<br\/>").replace(new RegExp("<!--(?!IMG)(.)*-->","gm"),"")
            article_page.date = content.ptime;
            article_page.title = content.title;
            article_page.replyCount = content.replyCount;
            article_page.replyBoard = content.replyBoard;
            var imgs = content.img;
            for(var k in imgs){
                var im = imgs[k];
                var autoImg = "http://s.cimg.163.com/i/"+im.src.replace(new RegExp("http://","gm"),"")+"."+(content_rect.width / 2 + 10) +"x"+(content_rect.width / 2) +".auto.jpg";
                articleBody = articleBody.replace(new RegExp(im.ref,"gm"), "<a href=\""+im.src+"-"+im.alt+"\" ><img width=\""+(content_rect.width / 2 + 10)+"\" height=\""+(content_rect.width / 2 )+"\" src="+autoImg+" align =\"right\" \/><\/a>");
            }


            articleBody += " (完)";

            var cs = articleBody.split("<br\/>");
            for(var c in cs){
                var ac = cs[c];
                listModel.append({
                                     "articleContent":ac
                                 });
            }
            //            article_page.body  += articleBody;
            article_page.hasNext = content.hasNext;
        }
        article_page.finish();

    }
}
