import QtQuick 1.0
import "Common.js" as Common
import "RunMemory.js" as MemoryUtil
import "Const.js" as Const

Rectangle {
    id: root
    width: 480; height: author_text.height + item_floor.height + text_rect.height + 30

    property string itemAuthor
    property string itemDate
    property alias itemComment: item_text.text

    property string boardId
    property string pId
    property string p
    property string upNum: "0"

    property bool created: true
    property bool hasHide: false

    property int totalFloor: 0
    property int rmouseY

    signal clicked

    MouseArea{
        id: option_area
        anchors.fill: parent

        onPressed: {
            console.debug("mouse Y:"+option_area.mouseY);
            root.rmouseY = option_area.mouseY;
        }

        onClicked:{
            console.debug("mouse Y:"+option_area.mouseY);
            root.clicked();
        }
    }

    gradient: Gradient {
        GradientStop { position: 0.0; color: "#EAEAEB" }
        GradientStop { position: 0.1; color: "#EDEDEE" }
        GradientStop { position: 1; color: "#EDEDEE" }
    }

    border{color: "#DDDDDD"; width: 1}

    ListModel{
        id: comment_model
    }

    Text{
        id: author_text
        color: Const.Color.author
         height: 35
        anchors{left: parent.left; leftMargin: 15; right: date_text.left; rightMargin: 10; top: parent.top}
        font{pointSize: 16}

        text: root.itemAuthor
        horizontalAlignment: Text.AlignLeft
        verticalAlignment: Text.AlignVCenter

        elide: Text.ElideRight
    }

    Text{
        id: date_text
        color: "#393939"
        font{pointSize: 16}
        anchors{right: parent.right; rightMargin: 15; top: parent.top}
        height: 35

        text: root.itemDate
        horizontalAlignment: Text.AlignRight
        verticalAlignment: Text.AlignVCenter
    }



    Item{
        id: item_floor
        width: parent.width - 30; height: floor_back.height
        anchors{left: author_text.left; top: author_text.bottom; topMargin: 2}
        CommentFloorBack{
            id: floor_back
            width: parent.width
            anchors{left:parent.left; top: parent.top}
        }

        Item{
            id: floor_item
            width: parent.width; height: floorR.height + topM.height
            anchors{left:parent.left; top: parent.top}
            Item{
                id: topM
                width: parent.width; height: comment_model.count > 4 ? 10 : comment_model.count * 2
            }
            Item{
                id: floorR
                width: parent.width; height: floor_content.height
                anchors{left: parent.left; top: topM.bottom}

            Column{
                id: floor_content
                Repeater{
                    model: comment_model
                    delegate:Item{
                        width: floor_item.width; height: fc.height

                        CommentRectangle{
                            anchors{horizontalCenter: parent.horizontalCenter; top: parent.top}
                        id: fc
                        author: f
                        comment: b
                        number: num
                        showLine: comment_model.count > 4 && index < (comment_model.count - 4)
                        isHide: hideCom
                        width: parent.width - 20

                        onClicked: {
                            root.createFullComment();
                        }
                        }
                        Component.onCompleted: {
                            floor_back.setBack(index, fc.height)
                        }
                    }
                }
            }
                    }
            }

    }

    Item{
        id: text_rect
        width: parent.width - 30 ; height: item_text.height
        anchors{horizontalCenter: parent.horizontalCenter; bottom: parent.bottom; bottomMargin: 20}

        Text {
            id: item_text
            font{pointSize: 18; wordSpacing: 2}
            wrapMode: Text.Wrap
            width: parent.width

            color: "#2C2C2C"
            textFormat: Text.RichText
        }
    }

    Component.onCompleted: {
    }

    function createComment(parentC, currentKey){
        var rect = Common.createMyObjects("CommentReplyBox.qml", parentC, currentKey, boxCallback);
        var content = Common.createMyObjects("CommentRectangle.qml", rect, currentKey, comCallback);
        return rect;
    }

    function comCallback(commentRect, parentC, currentKey){
//        commentRect.finishComponent(comment_model.get(0).currentFloors.f, comment_model.get(0).currentFloors.b, comment_model.get(0).currentFloors.number);
        commentRect.setModel(currentKey, comment_model.get(0).floors[currentKey])
        commentRect.width = parentC.width - 4;
        var nextFloor = getCurrentFloor(comment_model.get(0).floors, currentKey)
        if(parseInt(nextFloor) >= 0){
            console.debug("has more:"+nextFloor);
            if(parseInt(currentKey) - parseInt(nextFloor) === 1){
                var rect = createComment(parentC, nextFloor);
                commentRect.anchors.top = rect.bottom;
                commentRect.anchors.left = rect.left;
                parentC.height = commentRect.height + rect.height + 2;
            }else{
                console.debug("hide the floors");
                var hideRect = Common.createMyObjects("CommentReplyBox.qml", parentC, parseInt(nextFloor) - 1, boxCallback);
                var content = Common.createMyObjects("CommentHide.qml", hideRect, parseInt(nextFloor) - 1, hideCallback);
                commentRect.anchors.top = hideRect.bottom;
                commentRect.anchors.left = hideRect.left;
                parentC.height = commentRect.height + hideRect.height + 2;
            }
        }else{
            parentC.height = commentRect.height + 2;
            commentRect.anchors.horizontalCenter = parentC.horizontalCenter;
            commentRect.anchors.top = parentC.top;
            commentRect.anchors.topMargin = 2;
        }
    }

    function hideCallback(commentRect, parentC, currentKey){
        root.hasHide = true;
        commentRect.width = parentC.width - 4;
        var nextFloor = getCurrentFloor(comment_model.get(0).floors, currentKey);
        var rect = createComment(parentC, nextFloor);
        commentRect.anchors.top = rect.bottom;
        commentRect.anchors.left = rect.left;
        parentC.height = commentRect.height + rect.height + 2;
    }

    function boxCallback(commentRect, parentC, currentKey){
        var widthDel = 4;
        var topDel = 2;
        if(root.totalFloor > 7){
            widthDel = 0;
            topDel = 0;
        }
        commentRect.width = parentC.width - widthDel;
        commentRect.anchors.horizontalCenter = parentC.horizontalCenter;
        commentRect.anchors.top = parentC.top;
        commentRect.anchors.topMargin = topDel;


        root.totalFloor += 1;
    }

    function setModel(index, obj){
        if(root.created){
            var content = obj[index];
            root.itemAuthor = content.f;
            root.itemComment = content.b;
            root.p = content.p;
            root.upNum = content.v;
            root.itemDate = Common.getDate(content.t);
            createCommentModel(obj, index);
        }
    }

    function setHead(obj){
        if(root.created){
            root.itemAuthor = obj.f;
            root.itemComment = obj.b;
            root.p = obj.p;
            root.upNum = obj.v;
            root.itemDate = Common.getDate(obj.t);
//            createCommentModel(obj, index);
        }
    }

    function createCommentModel(obj, index){
        comment_model.clear();
        for(var i=0; i< parseInt(index); i++){
            var c = obj[i];
            if(c !== undefined && c !== null){
                console.debug(" add the floor:"+i);
                var isHide = 0;
                if(!obj[(i+1)]){
                    console.debug("hide the floor");
                    isHide = 1;
                }
                console.debug("is hide:"+isHide);
                console.debug("data:"+c.f+"|"+c.b+"|"+i+"|"+isHide);
                comment_model.append({
                                         "f": c.f,
                                         "b": c.b,
                                         "num": i,
                                         "hideCom": isHide
                                     });
            }
        }

//        var floorNum = getCurrentFloor(obj, index);
//            if(parseInt(current) > 0){
//                comment_model.append({
//                                 "currentFloor": current, "floors":obj
//                             });
//            }
//        }
    }


    function getCurrentFloor(obj, max){
        var maxFloor = "-1";
        for(var i in obj){
            console.debug("i:"+parseInt(i)+"; max:"+maxFloor);
            if(parseInt(i) < parseInt(max) && parseInt(i) > parseInt(maxFloor)){
                maxFloor = i;
                console.debug("maxFloor:"+maxFloor);
            }
        }
        if(parseInt(maxFloor) >= 0){
            return maxFloor;
        }else{
            return "-1";
        }
    }

    function createFullComment(){
        console.debug("root.boardId:"+root.boardId);
        Common.getStringByUrl("GET", "http://comment.api.163.com/api/json/post/load/"+root.boardId+"/"+root.pId+"_"+root.p, fullCommentCallback);

    }

    function fullCommentCallback(responseText){
        var obj = JSON.parse(responseText);
        if(obj.code === "1" || obj.code === "2"){

        root.itemDate = Common.getDate(obj.t);
        var floors = obj.b[0];
        var currentF = getCurrentFloor(floors, Number.MAX_VALUE)
        console.debug("current floor:"+currentF);

        createCommentModel(floors, currentF);
        }

    }

    function showBtnOpen(x, y){
        if(show_btn.visible){
            show_btn.visible = false;
        }else{
            if(y < 80){
                show_btn.y = root.y;
            }else{
                show_btn.y = root.y + y - 80;
                console.debug("show btn y:"+show_btn.y);
            }
            show_btn.visible = true;
        }
    }
}
