import QtQuick 1.1
import com.nokia.meego 1.0
import "Const.js" as Const
import "Common.js" as Common
import "Component"
import "RunMemory.js" as MemoryUtil
import "Database.js" as DBUtil

CustomPage {
    id: comment_page

    tools: toolbar

    property string docId
    property string replyBoard
    property string setId
    property string picIndex
    property string articleTId

    property int pageIndex: 0
    property int pageSize: 10

    property int totalSize: 0

    property string backType: Const.FavorateType.Article
    property string commentType: Const.Comment.Ties

    property string title

    property string currentP

    property int toolsStatus: 1

    property int replyType: 0
    property string replyPostId: ""

    property bool isFavorite: DBUtil.isFavoriteExists(comment_page.docId, Const.FavorateType.Comment);

    property bool hasNextPage: (comment_page.pageIndex) < totalSize

    TopBackGround{
        id: top_bar
        anchors{left: parent.left; top: parent.top}
        name: "跟帖"

        onClicked: {
            listView.positionViewAtBeginning();
        }
        BackButton{
            width: parent.height; height: parent.height
            anchors{left: parent.left; top: parent.top}
        }
        Rectangle{
            width: 120; height: parent.height
            color: Const.Color.rectTrans
            anchors{right: parent.right}

            CommentButton{
                width: 90; height: 55
                anchors.centerIn: parent

                name: comment_page.backType === Const.FavorateType.Pictrue ? "原图" : "原文"
                //                textBold: false

                onClicked: {
                    console.log("jump to comment page");
                    if(comment_page.backType === Const.FavorateType.Article){
                        pageStack.replace(Qt.resolvedUrl("ArticlePage.qml"),{docId:comment_page.docId, pageIndex: comment_page.picIndex, tid: comment_page.articleTId, commentType: comment_page.commentType, currentP: comment_page.currentP});
                    }else if(comment_page.backType === Const.FavorateType.Pictrue){
                        pageStack.replace(Qt.resolvedUrl("PicturePage.qml"),{docId:comment_page.setId, currentIndex: comment_page.picIndex});
                    }else if(comment_page.backType === Const.FavorateType.Comment){
                        pageStack.replace(Qt.resolvedUrl("TopicPage.qml"),{docId:comment_page.docId, pageIndex: comment_page.picIndex});
                    }

                }
            }
        }
    }

    Rectangle{
        color: Const.Color.background
        width: parent.width; height: parent.height - top_bar.height
        anchors{left: parent.left; top: top_bar.bottom}

        ReloadBackground{
            id: reload_back
            anchors.fill: parent
            visible: false
        }

        Flickable{
            id: flick_item
            flickableDirection: Flickable.VerticalFlick
            width: parent.width; height: parent.height
            contentWidth: Math.max(parent.width,main_comment.width)
            contentHeight: Math.max(parent.height,main_comment.height)

            pressDelay: 200

            onFlickStarted: {
                console.debug("flick start");
                option_rect.close();
            }

            onFlickingChanged: {
                console.debug("flick change");
                option_rect.close();
            }

            Item{
                id: main_comment
                width: comment_page.width; height: hot_comment.height + nomal_comment.height

                Item{
                    id: hot_comment
                    width: parent.width; height: hot_img.height + hot_content.height
                    anchors{left: parent.left; top: parent.top}

                    Item{
                        id: hot_img
                        width: parent.width; height: 60
                        anchors{top: parent.top; left: parent.left}
                        Image {
                            anchors{left:parent.left; verticalCenter: parent.verticalCenter}
                            source: comment_page.commentType === Const.Comment.Ties ? "images/comment_title_cola.png" : "images/comment_title_hottest.png"
                        }
                    }

                    Item{
                        id: hot_content
                        anchors{top: hot_img.bottom; left: parent.left}
                        width: parent.width; height: titleView.height

                        Column{
                            id: titleView
                            Repeater{
                                model: titleModel
                                delegate: listDelegate
                            }
                        }
                    }
                }

                Item{
                    id: nomal_comment
                    anchors{left: parent.left; top: hot_comment.bottom}
                    width: parent.width; height: nonal_img.height + nomal_content.height

                    Item{
                        id: nonal_img
                        width: parent.width; height: 60
                        anchors{top: parent.top; left: parent.left}
                        Image{
                            anchors{left:parent.left; verticalCenter: parent.verticalCenter}
                            source: "images/comment_title_newest.png"
                        }
                    }

                    Item{
                        id: nomal_content
                        width: parent.width; height: listView.height
                        anchors{top: nonal_img.bottom; left: parent.left}
                        Column{
                            id: listView
                            Repeater{
                                model: listModel
                                delegate: listDelegate

                                //            footer: list_footer
                            }

                            Item{
                                width: comment_page.width; height: comment_page.hasNextPage ? 80 : 0
                                visible: comment_page.hasNextPage
                                Rectangle{
                                    width: parent.width * 3 / 4; height: parent.height - 20
                                    anchors.centerIn: parent
                                    color: Const.Color.rectTrans
                                    Row{
                                        anchors.fill: parent
                                        Image{
                                            id: left_img
                                            width: 7; height: parent.height
                                            source: "images/button1_left.png"
                                        }

                                        Image {
                                            id: middle_img
                                            width: parent.width - left_img.width - right_img.width; height: parent.height
                                            source: "images/button1_mid.png"

                                        }
                                        Image{
                                            id: right_img
                                            width: 7; height: parent.height
                                            source: "images/button1_right.png"
                                        }
                                    }

                                    Text{
                                        color: "#464646"
                                        font{pointSize: Const.FontSize.menuSize}
                                        width: parent.width - 20; height: parent.height - 10

                                        anchors.centerIn: parent
                                        horizontalAlignment: Text.AlignHCenter
                                        verticalAlignment: Text.AlignVCenter

                                        text: "查看下"+comment_page.pageSize+"条"
                                    }

                                    PressArea{
                                        anchors.fill: parent
                                        pressRadius: 10
                                        onClicked: {
                                            comment_page.nextPage();
                                        }
                                    }
                                }
                            }

                        }

                    }
                }
            }

        }
        ScrollDecorator{
            flickableItem: flick_item
            platformStyle: ScrollDecoratorStyle{inverted: false}
        }

    }

    ListModel{
        id: listModel

    }

    ListModel{
        id: titleModel
    }

    Component{
        id: listDelegate
        CommentDelegate{
            id: item_create
            width: comment_page.width
            pId: comment_page.docId
            boardId: comment_page.replyBoard
            //            itemAuthor: currentFloor.f
            //            itemComment: currentFloor.b
            //            itemDate: Common.getDate(currentFloor.t)

            Component.onCompleted: {
                item_create.setModel(currentFloor,floors);
            }

            onClicked: {
                if(option_rect.visible){
                    option_rect.visible = false;
                }else{

                    var startY = 0;
                    if(type === "comment"){
                        startY = top_bar.height + item_create.y + hot_comment.height + nonal_img.height - flick_item.contentY;
                    }else{
                        startY = top_bar.height + item_create.y + hot_img.height - flick_item.contentY;
                    }

                    var currentY = startY;

                    if(item_create.rmouseY > (option_rect.height + 5)){
                        currentY += (item_create.rmouseY - (option_rect.height + 5));
                    }

                    var pid = item_create.p;
                    console.debug("contain:"+item_create.p.indexOf(comment_page.docId));
                    if(item_create.p.indexOf(comment_page.docId) < 0){
                        pid = comment_page.docId+"_"+item_create.p;
                    }

                    option_rect.open(currentY, comment_page.replyBoard, pid, item_create.upNum);
                }
            }

        }
    }
    NomalToolbar{
        id: toolbar

        isFavorited: comment_page.isFavorite
        favoriteVisible: false
        onReplyed: {
            comment_page.replyType = 0;
            reply_comment.open();
        }

        onFavorited: {
            if(comment_page.isFavorite){
                fav_dialog.open("您确定要取消该收藏吗?")
            }else{
                console.log("comment_page.replyBoard: "+comment_page.replyBoard)
                DBUtil.addCommentFavorite(comment_page.docId, comment_page.title, comment_page.replyBoard, comment_page.commentType, comment_page.currentP);
                comment_page.isFavorite = true;
                comment_page.showInfo("跟帖收藏成功");
            }
        }
    }

    ConfirmDialog{
        id: fav_dialog
        onAccepted: {
            DBUtil.removeSingleFavorite(comment_page.docId, Const.FavorateType.Comment);
            comment_page.isFavorite = false;
            comment_page.showInfo("跟帖收藏已经取消");
        }
    }


    CommentOption{
        id: option_rect
        anchors{horizontalCenter: parent.horizontalCenter}
        visible: true
        y: comment_page.height
        onUped: {
            comment_page.showInfo("顶贴成功");
        }

        onReplyed: {
            comment_page.replyType = 1;
            comment_page.replyPostId = option_rect.postId;
            reply_comment.open();
        }
    }

    HostInfo{
        id: hostinfo
    }
    ReplyToolbar{
        id: reply_comment

        anchors.fill: parent

        onSumbited: {
            console.debug("reply submit");
            replyComment();
        }
        onClosed: {
            toolbar.showImg();
        }
        visible: comment_page.toolsStatus === Const.Status.Opened
    }

    onLoaded: {
        option_rect.visible = false;
        getTitle();
    }

    function getTitle(){
        reload_back.visible = true;
        toolbar.favoriteVisible = false;
        if(comment_page.commentType === Const.Comment.Ties){
            Common.getStringByUrl("GET", "http://comment.api.163.com/api/json/post/load/"+comment_page.replyBoard+"/"+comment_page.docId+"_"+comment_page.currentP, hotCallback);
        }else{
            Common.getStringByUrl("GET", "http://comment.api.163.com/api/json/post/list/hot/"+comment_page.replyBoard+"/"+comment_page.docId+"/"+comment_page.pageIndex+"/5/5/1/1", hotCallback);
        }
    }

    function hotCallback(responseText){
        comment_page.connectioned()
        var fullObj = JSON.parse(responseText);
        if(fullObj.code !== "1" && fullObj.code !== "2"){
            comment_page.showInfo(fullObj.errMsg);
            comment_page.finish();
        }else{

            var array;
            if(comment_page.commentType === Const.Comment.Ties){
                array = fullObj.b;
            }else{
                array = fullObj.hotPosts;
            }
            for(var i in array){
                var obj = array[i];
                var current = getCurrentFloor(obj);
                console.debug("current floor:"+current);
                titleModel.append({
                                      "currentFloor": current,
                                      "floors": obj,
                                      "type":"hot"
                                  });
            }
            getComment();
        }
    }

    function getComment(){
        comment_page.connect();
        Common.getStringByUrl("GET", "http://comment.api.163.com/api/json/post/list/normal/"+comment_page.replyBoard+"/"+comment_page.docId+"/desc/"+comment_page.pageIndex+"/"+comment_page.pageSize+"/5/3/2", commentCallback);
    }

    function commentCallback(responseText){
        comment_page.connectioned();
        var obj = JSON.parse(responseText);
        comment_page.totalSize = obj.ptcount;
        var coms = obj.newPosts;
        for(var i in coms){
            createCommentModel(coms[i]);
        }
        comment_page.pageIndex += comment_page.pageSize;
        if(comment_page.pageIndex >= comment_page.totalSize){
            comment_page.pageIndex = comment_page.totalSize;
        }
        reload_back.visible = false;
        toolbar.favoriteVisible = true;
        comment_page.finish();
    }

    function createCommentModel(obj){
        var index = 0
        var current = getCurrentFloor(obj);
        console.debug("current floor:"+current);
        listModel.append({
                             "currentFloor": current,
                             "floors": obj,
                             "type":"comment"
                         });
    }

    function getCurrentFloor(obj){
        var maxFloor = "-1";
        for(var i in obj){
            if(parseInt(i) > parseInt(maxFloor)){
                maxFloor = i;
            }
        }
        if(parseInt(maxFloor) >= 0){
            return maxFloor;
        }else{
            return "-1";
        }
    }

    function nextPage(){
        comment_page.begin();
        if(comment_page.hasNextPage){
            getComment();
            //            Common.getStringByUrl("GET", "http://comment.api.163.com/api/json/post/list/normal/"+comment_page.replyBoard+"/"+comment_page.docId+"/desc/"+comment_page.pageIndex+"/"+comment_page.pageSize+"/5/3/2", commentCallback);
        }else{
            comment_page.finish();
        }
    }


    function replyComment(){
        var account = DBUtil.getAccount();
        if(account.username === undefined || account.username === null || account.username === ""){
            comment_page.showInfo("登录后才能跟贴");
            reply_comment.open();
            return;
        }
        if(reply_comment.text === ""){
            comment_page.showInfo("请填写跟帖内容");
            reply_comment.open();
            return;
        }
        var params = "board="+comment_page.replyBoard+"&threadid="+comment_page.docId+"&body="+reply_comment.text+"&userid="+account.username+"&nickname="+account.nickname+"&ip="+hostinfo.getLocalIp()+"&hidename=false";
        if(comment_page.replyType === 1){
            params += "&quote="+comment_page.replyPostId;
        }

        console.debug("params:"+params);
        comment_page.begin();
        reply_comment.finish();
        var doc = new XMLHttpRequest();
        doc.onreadystatechange = function() {
                    if ((doc.readyState == 4) && (doc.status == 200)) {
                        comment_page.connectioned();
                        console.debug(doc.responseText);
                        var obj = JSON.parse(doc.responseText);
                        comment_page.finish();
                        if(obj.code === "1"){
                            reply_comment.initReply();
                            toolbar.showImg();
                            comment_page.showInfo("您的帖子已经成功提交");
                        }else{
                            reply_comment.open();
                            comment_page.showInfo(obj.errMsg);
                        }
                    }
                }
        doc.open("POST", "http://comment.api.163.com/api/jsonp/post/insert", true);
        doc.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
        doc.send(params);
    }

}
