import QtQuick 1.1
import com.nokia.meego 1.0
import "Const.js" as Const
import "Common.js" as Common
import "Component"
import "Database.js" as DBUtil

CustomPage{
    id: favorite_main

    //    tools: BackToolBar{}

    property string currentType: Const.FavorateType.Article
    property string docidForDel

    TopSettingBack{
        id: top_bar
        anchors{left: parent.left; top: parent.top}
        name: "收藏夹"

        BackButton{
            width: parent.height; height: parent.height
            anchors{left: parent.left; top: parent.top}
        }
    }

    Rectangle{
        id: menu_bar
        width: parent.width; height: 70
        anchors{top: top_bar.bottom; left: parent.left}
        gradient: Gradient {
            GradientStop { position: 0.0; color: Const.Color.itemTop }
            GradientStop { position: 1; color: Const.Color.itemBottom }
        }
        //        border{color: Const.Color.itemBorder; width: 1}

        ReloadBackground{
            id: reload_back
            anchors.fill: parent
            visible: false
        }

        z: 10
        ListView{
            id: menu_view
            model: menu_model
            delegate: menu_delegate

            anchors.centerIn: parent
            width: parent.width * 3 / 4; height: 48

            orientation: ListView.Horizontal
            interactive: false
        }
    }

    ListModel{
        id: menu_model
        ListElement{name:"文章";aid:"Article"}
        ListElement{name:"图片";aid:"Pictrue"}
        ListElement{name:"跟帖";aid:"Comment"}
    }

    Component{
        id: menu_delegate
        Rectangle{
            width: 120; height: 48
            color: Const.Color.rectTrans
            MenuButton{
                anchors.fill: parent
                itemText: name
                visible: index === menu_view.currentIndex
            }
            Rectangle{
                anchors.fill: parent
                visible: index !== menu_view.currentIndex
                color: Const.Color.rectTrans
                Text{
                    color: "#898C8D"
                    text: name
                    font{pointSize: Const.FontSize.menuSize}
                    anchors.centerIn: parent
                }
            }
            MouseArea{
                anchors.fill: parent
                onClicked: {
                    changeMenu(index, aid);
                }
            }
        }
    }

    ListModel{
        id: listModel
    }


    Rectangle{
        id: pic_rect
        //        color: Const.Color.imageBack
        gradient: Gradient {
            GradientStop { position: 0.0; color: Const.Color.backgroundTop }
            GradientStop { position: 1; color: Const.Color.backgroundBottom }
        }
        width: parent.width;
        height: parent.height - top_bar.height - menu_bar.height
        visible: false
        anchors{left: parent.left; top: menu_bar.bottom}

        GridView{
            id: picView
            width: parent.width - 10; height: parent.height - 30
            anchors.centerIn: parent
            cellWidth: picView.width / 2; cellHeight: picView.cellWidth + 50

            model: listModel
            delegate: picDelegate

            footer: list_footer
        }

        ScrollDecorator{
            flickableItem: picView
            platformStyle: ScrollDecoratorStyle{inverted: false}
        }
    }

    Rectangle{
        id: fav_rect
        //        color: Const.Color.background
        gradient: Gradient {
            GradientStop { position: 0.0; color: Const.Color.backgroundTop }
            GradientStop { position: 1; color: Const.Color.backgroundBottom }
        }
        width: parent.width; height: parent.height - top_bar.height - menu_bar.height
        anchors{left: parent.left; top: menu_bar.bottom}
        visible: false

        ListView{
            id: listView
            width: parent.width - 10; height: parent.height - 30
            anchors.centerIn: parent

            model: listModel
            delegate: artDelegate

            footer: list_footer
        }

        ScrollDecorator{
            flickableItem: listView
            platformStyle: ScrollDecoratorStyle{inverted: false}
        }
    }

    Component{
        id: artDelegate

        Item{
            width: favorite_main.width; height: 80
            //            anchors.centerIn: parent
            //            gradient: Gradient {
            //                GradientStop { position: 0.0; color: "#EAEAEB" }
            //                GradientStop { position: 0.1; color: "#EDEDEE" }
            //                GradientStop { position: 1; color: "#EDEDEE" }
            //            }
            //            border{color: "#DDDDDD"; width: 1}

            Text{
                id: footer_text
                color: Const.Color.listTitle
                font{pointSize: Const.FontSize.menuSize; bold: true}
                width: parent.width - 30; height: parent.height - 10
                anchors.centerIn: parent
                horizontalAlignment: Text.AlignLeft
                verticalAlignment: Text.AlignVCenter

                elide: Text.ElideRight
                text: title
            }

            PressArea{
                anchors.fill: parent

                onClicked: {
                    if(favType === Const.FavorateType.Article){
                        pageStack.push(Qt.resolvedUrl("ArticlePage.qml"), {docId: docid});
                    }else if(favType === Const.FavorateType.Comment){
                        console.debug("comment replyBorad:"+ replyBorad);
                        pageStack.push(Qt.resolvedUrl("CommentPage.qml"), {docId: docid, replyBoard: replyBorad, commentType: commentType, currentP: curP, title:title});
                    }else{
                        console.log("Error: type error:"+favType);
                    }
                }

                onPressAndHolded:{
                    favorite_main.currentType = favType;
                    favorite_main.docidForDel = docid;
                    remove_dialog.open("您确定要删除该收藏吗");
                }
            }
            Image {
                id: line
                source: "images/line.png"
                width: parent.width
                anchors{left: parent.left; bottom: parent.bottom}
            }
        }

    }


    Component{
        id: list_footer
        Rectangle{
            width: favorite_main.width; height: 180
            color: Const.Color.rectTrans

            Rectangle{
                width: parent.width * 3 / 4; height: 60
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.top: parent.top
                anchors.topMargin : 5
                color: Const.Color.rectTrans
                Row{
                    anchors.fill: parent
                    Image{
                        id: left_img
                        width: 7; height: parent.height
                        source: "images/button1_left.png"
                    }

                    Image {
                        id: middle_img
                        width: parent.width - left_img.width - right_img.width; height: parent.height
                        source: "images/button1_mid.png"

                    }
                    Image{
                        id: right_img
                        width: 7; height: parent.height
                        source: "images/button1_right.png"
                    }
                }

                Text{
                    id: footer_text
                    color: "#464646"
                    font{pointSize: Const.FontSize.menuSize}
                    width: parent.width - 20; height: parent.height - 10
                    anchors.centerIn: parent

                    horizontalAlignment: Text.AlignHCenter
                    verticalAlignment: Text.AlignVCenter

                    text: "取消该类所有收藏"
                }

                PressArea{
                    anchors.fill: parent
                    pressRadius: 10

                    onClicked: {
                        deleteAll_dialog.open("您确定要清空该类收藏吗");
                    }
                }
            }
        }

    }

    Component{
        id: picDelegate

        Item{
            width: picView.cellWidth; height: picView.cellHeight
            Item{
                id: img_back
                //            color: Const.Color.rectTrans
                width: parent.width - 20 ; height: parent.width - 20;
                anchors{horizontalCenter: parent.horizontalCenter; top: parent.top; topMargin: 20}
                Image{
                    anchors.fill: parent
                    source: "images/imageset_list_itemback.png"
                }

                Rectangle{
                    id: img_path
                    anchors.centerIn: parent
                    width: parent.width * 7 / 8; height: parent.height * 7 / 8
                    color: Const.Color.rectTrans

                    Image{
                        anchors.fill: parent
                        source: img
                    }
                }
            }

            Item{
                id: img_title
                //            color: Const.Color.rectTrans
                anchors{horizontalCenter: parent.horizontalCenter; bottom: parent.bottom}
                width: parent.width; height: 50

                Text{
                    anchors.centerIn: parent
                    font{pointSize: 16}
                    color: "#2C2C2C"
                    text: title
                    width: parent.width - 20; height: parent.height - 10
                    horizontalAlignment: Text.AlignLeft
                    verticalAlignment: Text.AlignVCenter

                    wrapMode: Text.WordWrap
                }
            }

            PressArea{
                anchors.fill: parent

                onClicked: {
                    console.log("jump to single image:"+docid);
                    pageStack.push(Qt.resolvedUrl("PicturePage.qml"),{docId:docid, picSetImg:img});
                }
            }

        }
    }

    BusyLoading{
        id: loading
        anchors.centerIn: parent
    }

    InfoShow{
        id: infoShow
        anchors{bottom: parent.bottom; bottomMargin: 50}
    }

    ConfirmDialog{
        id: remove_dialog
        onAccepted: {
            deleteSingle(favorite_main.docidForDel, favorite_main.currentType);
        }
    }


    ConfirmDialog{
        id: deleteAll_dialog
        onAccepted: {
            removeAll();
        }
    }

    onLoaded:  {
        favorite_main.finish();
    }

    onStatusChanged: {
        if(PageStatus.Active === favorite_main.status){
            console.debug("favorite page actived");
            reload();
        }
    }

    function changeMenu(index, aid){
        favorite_main.begin();
        menu_view.currentIndex = index;
        listModel.clear();
        favorite_main.currentType = aid;

        getFavorite(aid);
        if(aid === Const.FavorateType.Article){
            fav_rect.visible = true;
            fav_rect.height = favorite_main.height - top_bar.height - menu_bar.height;
            pic_rect.height = 0;
            pic_rect.visible = false;
        }else if(aid === Const.FavorateType.Comment){
            fav_rect.visible = true;
            fav_rect.height = favorite_main.height - top_bar.height - menu_bar.height;
            pic_rect.height = 0;
            pic_rect.visible = false;
        }else{
            fav_rect.height = 0;
            fav_rect.visible = false;
            pic_rect.visible = true;
            pic_rect.height = favorite_main.height - top_bar.height - menu_bar.height;
        }
        reload_back.visible = false;
        favorite_main.finish();
    }

    function getFavorite(favType){
        var obj = DBUtil.getFavorites(favType);
        for(var i in obj){
            var f = obj[i];
            console.log("f.replyBorad"+f.replyBoard)
            listModel.append({
                                 "docid": f.docId,
                                 "title": f.title,
                                 "img": f.img,
                                 "replyBorad": f.replyBoard,
                                 "favType": f.favType,
                                 "commentType": f.commentType,
                                 "curP": f.currentP
                             });
        }
        console.debug("listmodel.count:"+listModel.count);
    }

    function reload(){
        favorite_main.begin();
        reload_back.visible = true;
        //        listModel.clear();
        //        getFavorite(favorite_main.currentType);
        changeMenu(menu_view.currentIndex, favorite_main.currentType);
    }

    function deleteSingle(docid, favType){
        DBUtil.removeSingleFavorite(docid, favType);
        reload();
    }

    function removeAll(){
        favorite_main.begin();
        DBUtil.removeFavorites(favorite_main.currentType);
        reload();
        favorite_main.showInfo("删除成功");
    }
}
