import QtQuick 1.1
import com.nokia.meego 1.0
import "Common.js" as Common
import "Const.js" as Const

Page {
    id: feedback_page

    orientationLock: PageOrientation.LockPortrait

//    tools: BackToolBar{}

    property int count: 500

    TopSettingBack{
        id: top_bar
        anchors{left: parent.left; top: parent.top}
        name: "用户反馈"

        BackButton{
            width: parent.height; height: parent.height
            anchors{left: parent.left; top: parent.top}
        }
    }

    Rectangle{
        width: parent.width; height: parent.height - top_bar
        anchors{left: parent.left; top: top_bar.bottom}
        color: Const.Color.background
        Item{
            id: desc_item
            width: parent.width - 30; height: 60
            anchors{horizontalCenter: parent.horizontalCenter; top: parent.top}
            Text{
                anchors{right: parent.right; verticalCenter: parent.verticalCenter}
                color: "red"
                font{pointSize: 18}
                text: "您还可以输入"+feedback_page.count+""

                horizontalAlignment: Text.AlignRight
                verticalAlignment: Text.AlignVCenter
            }
        }

        Rectangle{
            id: feedback_content
            width: parent.width - 30; height: 200;
            anchors.top: desc_item.bottom
            anchors.horizontalCenter: parent.horizontalCenter
            border{color: Const.Color.listWord; width: 1}
            radius: 10
            Text{
                id: placeholder
                font{pointSize: 18}
                color: Const.Color.listWord
                text: "请填写反馈信息，谢谢支持"
                width: parent.width; height: 50

                horizontalAlignment: Text.AlignLeft
                verticalAlignment: Text.AlignVCenter
                anchors{left: parent.left; leftMargin: 10; top: parent.top}
            }

        Flickable {
              id: flick
              width: parent.width - 20; height: parent.height - 30
              anchors.centerIn: parent
              contentWidth: edit.paintedWidth
              contentHeight: edit.paintedHeight
              flickableDirection: Flickable.VerticalFlick
              clip: true

              function ensureVisible(r)
              {
                  if (contentX >= r.x)
                      contentX = r.x;
                  else if (contentX+width <= r.x+r.width)
                      contentX = r.x+r.width-width;
                  if (contentY >= r.y)
                      contentY = r.y;
                  else if (contentY+height <= r.y+r.height)
                      contentY = r.y+r.height-height;
              }

              TextEdit {
                                id: edit
                                width: flick.width
                                height: flick.height
                                anchors.leftMargin: 100
                                font.pointSize: 18
                                textFormat: TextEdit.PlainText
                                focus: false
                                wrapMode: TextEdit.Wrap

                                onCursorRectangleChanged:{

                                    flick.ensureVisible(cursorRectangle);

                                    checkLength();
                                }
                                activeFocusOnPress: false
                                MouseArea {
                                        anchors.fill: parent
                                        onClicked: {
                                            if (!edit.activeFocus) {
                                                edit.readOnly=false;
                                                edit.forceActiveFocus();
                                                edit.openSoftwareInputPanel();
                                            } else {
                                                edit.focus = false;
                                            }
                                        }
                                        onPressAndHold: edit.closeSoftwareInputPanel();
                                    }
                                onActiveFocusChanged: {
                                        if (edit.focus) {
                                            feedback_content.border.color = "blue";//Const.Color.listWord
                                            closeSoftwareInputPanel();
                                            placeholder.text = "";

                                        } else{
                                            if(edit.text === ""){
                                                placeholder.text = "请填写反馈信息，谢谢支持";
                                            }
                                            feedback_content.border.color = Const.Color.listWord;
                                            closeSoftwareInputPanel();
                                           // Popup.close(edit);
                                        }
                                    }

                            }
        }
        }

        Item{
            id: email_item
            anchors{horizontalCenter: parent.horizontalCenter; top: feedback_content.bottom}
            width: parent.width - 30; height: 80
            TextField{
                id: email
                placeholderText: "选填，便于我们与您联系"
                anchors{verticalCenter: parent.verticalCenter}
                width: parent.width; height: 60
                Text{
                    id: left_text
                    anchors{left: parent.left; leftMargin: 10; verticalCenter: parent.verticalCenter}
                    width: 120; height: 50
                    text: "您的邮箱:"
                    color: "black"
                    font{pointSize: 18}

                    horizontalAlignment: Text.AlignLeft
                    verticalAlignment: Text.AlignVCenter


                }
                platformStyle: TextFieldStyle{paddingLeft: left_text.width + 10}
            }
        }

        Item{
            width: parent.width; height: 80
            anchors{horizontalCenter: parent.horizontalCenter; top: email_item.bottom; topMargin: 20}
            Rectangle{
                width: parent.width * 3 / 4; height: parent.height - 20
                anchors.centerIn: parent
                color: Const.Color.rectTrans
        Row{
            anchors.fill: parent
            Image{
                id: left_img
                width: 7; height: parent.height
                source: "images/button1_left.png"
            }

            Image {
                id: middle_img
                width: parent.width - left_img.width - right_img.width; height: parent.height
                source: "images/button1_mid.png"

            }
            Image{
                id: right_img
                width: 7; height: parent.height
                source: "images/button1_right.png"
            }
        }

                Text{
                    color: "#464646"
                    font{pointSize: 22}
                    width: parent.width - 20; height: parent.height - 10
                    anchors.centerIn: parent

                    horizontalAlignment: Text.AlignHCenter
                    verticalAlignment: Text.AlignVCenter

                    text: "提交反馈"
                }

                PressArea{
                    anchors.fill: parent
                    pressRadius: 10
                    onClicked: {
                        console.debug("submit the feed back");
                        submit();
                    }
                }
            }
        }

    }
    InfoShow{
        id: infoShow
        anchors{bottom: parent.bottom; bottomMargin: 50}
    }

    BusyLoading{
        id: loading
        anchors.centerIn: parent
    }

    Timer {
        id: timeWait
             interval: 500; running: false; repeat: false
             onTriggered: pageStack.pop();
     }

    function submit(){

        if(edit.text === ""){
            infoShow.open("请填写反馈信息");
            return;
        }
        var params = "boardid=newsfeedback&title=[Nokia_Meego_N9]客户端反馈&comment="+edit.text;
        if(email.text !== ""){
            if(Common.isEmail(email.text)){
                params += "&email="+email.text;
            }else{
                infoShow("邮箱格式错误");
                return;
            }
        }
        loading.open();
        var doc = new XMLHttpRequest();
        doc.onreadystatechange = function() {
            if ((doc.readyState == 4) && (doc.status == 200)) {
                console.debug(doc.responseText);
                if(doc.responseText.indexOf("您的反馈已经成功提交") > 0){
                    infoShow.open("您的反馈已经成功提交!");
                    loading.close();
                    timeWait.running = true;
                }else{
                    infoShow.open("反馈提交失败");
                    loading.close();
                }

            }
            console.debug(doc.readyState);
        }
        doc.open("POST", "http://3g.163.com/bbs/bbs_news/3g/feedback.do", true);
        doc.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
        doc.send(params);
    }

    function checkLength(){
        var msg =edit.text;
        var maxlength = 500;
        if(edit.text.length > maxlength)
         {
           edit.text= msg.substring(0,maxlength);
         }
        feedback_page.count = maxlength-edit.text.length;
     }
}
