import QtQuick 1.0
import com.nokia.meego 1.0
import "Const.js" as Const
import "Common.js" as Common
import "Database.js" as DBUtil
import "RunMemory.js" as MemoryUtil

CustomPage {
    id: more_page

    property string title
    property string tid

    property int pageIndex: 0
    property int pageSize: 10

    //    tools: BackToolBar{}

    onLoaded: {
        console.debug("more page load finish");
        reload_back.visible = true;
        getList();
    }

    TopBackGround{
        id: top_bar
        anchors{left: parent.left; top: parent.top}
        name: more_page.title

        onClicked: {
            console.log("go to top");
            news_list.positionViewAtBeginning();
        }

        BackButton{
            width: parent.height; height: parent.height
            anchors{left: parent.left; top: parent.top}
        }
    }

    Rectangle{
        width: parent.width; height: parent.height - top_bar.height
        anchors{left: parent.left; top: top_bar.bottom}
        color: Const.Color.background

        ReloadBackground{
            id: reload_back
            anchors.fill: parent
            visible: false
        }

        ListView{
            id: news_list
            anchors.fill: parent

            model: listModel
            delegate: listDelegate

            //            header: listHeader
            //            footer: list_footer
        }

        ScrollDecorator{
            flickableItem: news_list
            platformStyle: ScrollDecoratorStyle{inverted: false}
        }
    }

    ListModel{
        id: listModel

    }

    Component{
        id: list_footer
        Item{
            width: more_page.width; height: 80
            Rectangle{
                width: parent.width * 3 / 4; height: parent.height - 20
                anchors.centerIn: parent
                color: Const.Color.rectTrans
                Row{
                    anchors.fill: parent
                    Image{
                        id: left_img
                        width: 7; height: parent.height
                        source: "images/button1_left.png"
                    }

                    Image {
                        id: middle_img
                        width: parent.width - left_img.width - right_img.width; height: parent.height
                        source: "images/button1_mid.png"

                    }
                    Image{
                        id: right_img
                        width: 7; height: parent.height
                        source: "images/button1_right.png"
                    }
                }

                Text{
                    color: "#464646"
                    font{pointSize: Const.FontSize.menuSize}
                    width: parent.width - 20; height: parent.height - 10

                    horizontalAlignment: Text.AlignHCenter
                    verticalAlignment: Text.AlignVCenter
                    anchors.centerIn: parent

                    text: "查看下"+more_page.pageSize+"条"
                }

                PressArea{
                    anchors.fill: parent
                    pressRadius: 10

                    onClicked: {
                        more_page.nextPage();
                    }
                }
            }
        }
    }

    Component{
        id: listDelegate

        Item{
            width: parent.width; height: 120
            NewsListDelegate{
                anchors.fill: parent

                itemContent: content
                itemSource: img
                itemTitle: title
                itemType: itemType
                replyCount: itemReply
                docid: articleId
                isReaded: MemoryUtil.isArticleReaded(articleId)

                onClicked: {
                    DBUtil.addReadStatus(Const.ReadStatus.Article, articleId);
                    MemoryUtil.addArticleRead(articleId);
                    pageStack.push(Qt.resolvedUrl("ArticlePage.qml"),{docId:articleId,tid:more_page.tid,pageIndex: index});

                }
            }

        }
    }

    function getList(){
        news_list.footer = null;
        Common.getStringByUrl("GET", "http://c.3g.163.com/nokia/nc/article/list/"+more_page.tid+"/"+more_page.pageIndex+"-"+more_page.pageSize+".html", newsCallback);

    }

    function newsCallback(responseText){
        var obj = JSON.parse(responseText);

        for(var i in obj){
            createModelFromJson(obj[i]);
        }
        more_page.pageIndex += more_page.pageSize;
        news_list.footer = list_footer;
        reload_back.visible = false;
        more_page.finish();
    }

    function createModelFromJson(obj){
        console.log("create model");
        var hasImg = true;
        for(var k in obj){
            var check = obj[k];
            if(check.imgsrc === ""){
                hasImg = false;
                break;
            }
        }
        for(var i in obj){
            var c = obj[i];

            listModel.append({
                                 "articleId":c.docid,
                                 "content":c.digest,
                                 "img":hasImg ? c.imgsrc : "",
                                                "title":c.title,
                                                "itemType": 0,
                                                "itemReply": c.replyCount
                             });

        }

    }

    function nextPage(){
        more_page.begin();
        getList();
    }
}
