import QtQuick 1.1
import com.nokia.meego 1.0
import "Const.js" as Const
import "Common.js" as Common
import "Component"
import "RunMemory.js" as MemoryUtil
import "Database.js" as DBUtil

Page {
    id: news_main
    orientationLock: PageOrientation.LockPortrait

    property bool isSettingOpen: false
    property int menuStatus: Const.Status.Closed

    property string imgSource
    property string imgContent
    property string imgDocid
    property int imgReplyCount
    property int imgType: 0

    property int pageIndex: 0
    property int pageSize: 10

    property string currentTid
    property bool btn_enabled: true

    TopBackGround{
        id: top_bar
        anchors{left: parent.left; top: parent.top}
        name: "新闻"

        onClicked: {
            console.log("go to top");
            news_list.positionViewAtBeginning();
        }

        ReloadButton{
            id: reload_rect
            width: parent.height; height: parent.height
//            color: Const.Color.rectTrans
            anchors{left: parent.left; top: parent.top}

            onClicked: {

                  changeMenu(menu_view.currentIndex ,news_main.currentTid);
//                    mainPage.pageStack.push(Qt.resolvedUrl("InfoMainPage.qml"),{reflashPage: "news"});
            }
//            }
        }


        Rectangle{
            id: setting_rect
            width: parent.height; height: parent.height
            color: Const.Color.rectTrans
            anchors{right: parent.right; top: parent.top}

            Item{
                id: setting_btn
                width: 55; height: 55
                anchors.centerIn: parent
                Image{
                    source: "images/setting.png"
                    anchors.fill: parent
                }
            }
            MouseArea{
                anchors.fill: parent

                onClicked: {
//                    news_main.openSettingMenu();
                    mainPage.pageStack.push(Qt.resolvedUrl("InfoMainPage.qml"),{reflashPage: "news"});
                }
            }
        }

    }


    Rectangle{
        id: menu_bar
        width: parent.width; height: 70
        anchors{top: top_bar.bottom; left: parent.left}
        gradient: Gradient {
            GradientStop { position: 0.0; color: Const.Color.itemTop }
            GradientStop { position: 1; color: Const.Color.itemBottom }
        }
//        border{color: Const.Color.itemBorder; width: 1}
        z: 10
        ListView{
            id: menu_view

            model: menu_model
            delegate: menu_delegate

            anchors.centerIn: parent
            width: parent.width - 30; height: 48

            orientation: ListView.Horizontal

            onFlickEnded: {
                if(menu_view.contentX === 0){
                    left_cell.visible = false;
                }else if(menu_view.contentX > 0){
                    left_cell.visible = true;
                }

                if(menu_view.atXEnd){
                    right_cell.visible = false;
                }else{
                    right_cell.visible = true;
                }
            }
        }

        Rectangle{
            id: left_cell
            visible: false
            width: 15; height: parent.height
            color: Const.Color.rectTrans
            anchors{left: parent.left; top: parent.top}
            Image{
                source: "images/left.png"

                anchors.centerIn: parent
                width: parent.width; height: 30
            }

        }

        Rectangle{
            id: right_cell
            visible: false
            width: 15; height: parent.height
            color: Const.Color.rectTrans
            anchors{right: parent.right; top: parent.top}
            Image{
                source: "images/right.png"
                anchors.centerIn: parent
                width: parent.width; height: 30
            }

        }
    }

    ListModel{
        id: menu_model
    }

    Component{
        id: menu_delegate

        Rectangle{
            width: 75; height: 48
            color: Const.Color.rectTrans
            Rectangle{
                anchors.centerIn: parent
                width: 70; height: 48

                color: Const.Color.rectTrans
                MenuButton{
                    anchors.fill: parent
                    itemText: tname
                    visible: index === menu_view.currentIndex
                }
                Rectangle{
                    anchors.fill: parent
                    visible: index !== menu_view.currentIndex
                    color: Const.Color.rectTrans
                    Text{
                        color: Const.Color.menuText
                        text: tname
                        font{pointSize: Const.FontSize.menuSize; bold: true}
                        anchors.centerIn: parent
                    }
                }
            }
            MouseArea{
                anchors.fill: parent
                onClicked: {
                    if(menu_view.currentIndex !== index){
                        changeMenu(index, tid);
                    }
                }
            }

        }
    }

    Rectangle{
        id: news_content
        anchors{top: menu_bar.bottom; left: parent.left}
        width: parent.width; height: parent.height - top_bar.height - menu_bar.height
        gradient: Gradient {
            GradientStop { position: 0.0; color: Const.Color.backgroundTop }
            GradientStop { position: 1; color: Const.Color.backgroundBottom }
        }


        ReloadBackground{
            id: reload_back
            anchors.fill: parent
            visible: false
        }

        ListView{
            id: news_list
            anchors.fill: parent

            model: listModel
            delegate: listDelegate

//            header: listHeader
//            footer: list_footer
        }

        ScrollDecorator{
            flickableItem: news_list
            platformStyle: ScrollDecoratorStyle{inverted: false}
        }
    }

    ListModel{
        id: listModel

    }

    Component{
        id: listHeader

        Item{
            width: news_main.width; height: 255


        Rectangle{
            anchors.fill: parent
            color: Const.Color.rectTrans
            ImageLoadBackground{
                width: parent.width; height: parent.height
//                color: Const.Color.rectTrans
                Image{
                    anchors.fill: parent
                    source: news_main.imgSource
                }

                Item{
                    width: parent.width; height: 45
                    anchors.left: parent.left; anchors.bottom: parent.bottom

                    Rectangle{
                        color: "black"
                        opacity: 0.5
                        anchors.fill: parent
                        border{color: "#828282"; width: 1}
                    }

                    Text{
                        font{pointSize: Const.FontSize.menuSize}
                        color: "white"
                        anchors.centerIn: parent

                        width: parent.width - 20; height: parent.height - 20
                        horizontalAlignment: Text.AlignLeft
                        verticalAlignment: Text.AlignVCenter

                        text: news_main.imgContent
                    }

                    Rectangle{
                        width: 45; height: 20
                        color: "#AD1621"

                        radius: 8
                        anchors{right: parent.right; rightMargin: 65; verticalCenter: parent.verticalCenter}
                        visible: news_main.imgType === 1

                        Text{
                            text: "专题"
                            color: "white"
                            font{pointSize: 14}

                            anchors.fill: parent

                            horizontalAlignment: Text.AlignHCenter
                            verticalAlignment: Text.AlignVCenter
                        }
                    }
                }
            }

            PressArea{
                id: header_area
                anchors.fill: parent

                onClicked: {
                    mainPage.pageStack.push(Qt.resolvedUrl("ArticlePage.qml"),{docId: news_main.imgDocid,tid:news_main.currentTid,pageIndex: 0});
                }
            }

        }
       }

    }

    Component{
        id: list_footer
        Item{
            width: news_main.width; height: 80
            Rectangle{
                width: parent.width * 3 / 4; height: parent.height - 20
                anchors.centerIn: parent
                color: Const.Color.rectTrans
        Row{
            anchors.fill: parent
            Image{
                id: left_img
                width: 7; height: parent.height
                source: "images/button1_left.png"
            }

            Image {
                id: middle_img
                width: parent.width - left_img.width - right_img.width; height: parent.height
                source: "images/button1_mid.png"

            }
            Image{
                id: right_img
                width: 7; height: parent.height
                source: "images/button1_right.png"
            }
        }

                Text{
                    color: "#464646"
                    font{pointSize: Const.FontSize.menuSize}
                    width: parent.width - 20; height: parent.height - 20
                    anchors.centerIn: parent
                    horizontalAlignment: Text.AlignHCenter
                    verticalAlignment: Text.AlignVCenter

                    text: "查看下"+news_main.pageSize+"条"
                }

                PressArea{
                    id: nextPage_btn
                    anchors.fill: parent
                    enabled: news_main.btn_enabled
                    pressRadius: 10
                    onClicked: {
                        news_main.btn_enabled = false;
                        news_main.nextPage();
                    }
                }
            }
        }
    }

    Component{
        id: listDelegate

        Item{
            width: parent.width; height: 118
            NewsListDelegate{
                anchors.fill: parent

                itemContent: content
                itemSource: img
                itemTitle: title
                itemType: itemType
                replyCount: itemReply
                docid: articleId
                isReaded: MemoryUtil.isArticleReaded(articleId)

                onClicked: {
                    DBUtil.addReadStatus(Const.ReadStatus.Article, articleId);
                    MemoryUtil.addArticleRead(articleId);
                    mainPage.pageStack.push(Qt.resolvedUrl("ArticlePage.qml"),{docId:articleId,tid:news_main.currentTid,pageIndex: index + 1});

                }
            }

        }
    }

    Component{
        id: moreDelegate

        Rectangle{
            id: more_rect
            gradient: Gradient {
                GradientStop { position: 0.0; color: "#EAEAEB" }
                GradientStop { position: 0.1; color: "#EDEDEE" }
                GradientStop { position: 1; color: "#EDEDEE" }
            }

//            border{color: "#DDDDDD"; width: 1}
            width: news_main.width; height: 80
            Item{
                width: parent.width; height: parent.height
                Row{
                    anchors.fill: parent
                    Item{
                        width: 15; height: parent.height
                    }
                    Text{
                        id: content_title
                        font{pointSize: 20; bold: true}
                        color: Const.Color.listTitle
                        width: 427; height: parent.height
                        text: title

                        horizontalAlignment: Text.AlignLeft
                        verticalAlignment: Text.AlignVCenter

                        elide: Text.ElideRight
                    }
                    Item{
                        width: 8; height: parent.height
                    }
                    Rectangle{
                        width: 30; height: parent.height
                        color: Const.Color.rectTrans
                        Image{
                            anchors{left: parent.left; verticalCenter: parent.verticalCenter}
                            source: "images/cell_right_arraw.png"
                        }
                    }
                }



            }

            PressArea{
                anchors.fill: parent

                onClicked: {
                    mainPage.pageStack.push(Qt.resolvedUrl("MoreColumnsPage.qml"), {title:title, tid: articleId});
                }
            }

            Image {
                id: line
                source: "images/line.png"
                width: parent.width
                anchors.left: parent.left
                anchors.bottom: parent.bottom
            }
        }
    }
    BusyLoading{
        id: loading
        anchors.centerIn: parent
    }

    Component.onCompleted: {
        console.log("news_main completed");
        loading.open();
        getNewsTopics();
//        changeMenu(0,"T1295501906343");
    }

    onStatusChanged: {
        if(PageStatus.Active === news_main.status){
            console.log("page actived ");
            news_main.menuStatus = Const.Status.Closed;

            if(MemoryUtil.columnsChanged){
                MemoryUtil.columnsChanged = false;
                getNewsTopics();
            }
        }


    }

    function changeMenu(index, tid){
        loading.open();
        reload_back.visible = true;
        news_main.pageIndex = 0;
        menu_view.currentIndex = index;
        news_main.currentTid = tid;
        listModel.clear();
        news_list.header = null;
        news_list.footer = null;
        if(tid === "TMORE"){
            news_list.delegate = moreDelegate;
            moreCallback();
        }else {
            news_list.delegate = listDelegate;
            if(index === 0){// 头条ID
                Common.getStringByUrl("GET","http://c.3g.163.com/nokia/nc/article/headline/"+news_main.currentTid+"/"+news_main.pageIndex+"-"+news_main.pageSize+".html", headlineCallback);

            }else{
                Common.getStringByUrl("GET", "http://c.3g.163.com/nokia/nc/article/list/"+news_main.currentTid+"/"+news_main.pageIndex+"-"+news_main.pageSize+".html", newsCallback);
            }
        }
    }

    function moreCallback(){
        var cols = DBUtil.getNonColumns();
        console.debug("cols length:"+ cols.length);
        for(var i in cols){
            var m =cols[i];
            console.debug("more:"+m.tname);
            if("T1295501906343" !== m.tid){
            listModel.append({
                                 "articleId":m.tid,
                                 "content": "",
                                 "img": "",
                                 "title":m.tname,
                                 "itemType": 0,
                                 "itemReply": 0
                             });
            }
        }
        reload_back.visible = false;
        loading.close();
    }

    function headlineCallback(responseText){
        var obj = JSON.parse(responseText);
        news_list.header = listHeader;
        for(var i in obj){
            createModelFromJson(obj[i]);
        }
        news_main.pageIndex += 10;
        news_list.footer = list_footer;
        reload_back.visible = false;
        loading.close();
    }

    function newsCallback(responseText){
        var obj = JSON.parse(responseText);

        for(var i in obj){
            createModelFromJson(obj[i]);
        }
        news_main.pageIndex += 10;
        news_list.footer = list_footer;
        reload_back.visible = false;
        news_main.btn_enabled = true;
        loading.close();
    }

    function getNewsTopics(){
        console.log("get news topics");
        var cols = DBUtil.getColumns();
        console.debug("column length:"+cols.length);
        createMenu(cols);
        changeMenu(0,news_main.currentTid);

    }

    function getMoreTopics(){
        console.log("gettopics");
        Common.getStringByUrl("GET", "http://c.3g.163.com/nokia/nc/topicset/default.html", newsTopicsCallback);

    }

    function createMenu(obj){
        menu_model.clear();
        menu_model.append({"tname":"头条","tid":"T1295501906343"});
        news_main.currentTid = "T1295501906343";
        for(var i in obj){
            console.debug("column i:"+i);
            var m =obj[i];
            console.debug("INFO tname:"+m.tname+"; tid:"+m.tid);
            menu_model.append({
                               "tname":m.tname,
                               "tid":m.tid
                              });
        }
        if(obj.length < 31){
        menu_model.append({
                              "tname":"更多",
                              "tid":"TMORE"
                          });
        }
        console.debug("menu_view.contentWidth:"+menu_view.contentWidth);
        console.debug("news_main.width:"+news_main.width);
        console.debug("menu_model.count:"+menu_model.count);
        if(menu_model.count > 6){
            right_cell.visible = true;
        }
    }

    function createModelFromJson(obj){
        console.log("create model");
        var hasImg = true;
        for(var k in obj){
            var check = obj[k];
            if(check.imgsrc === ""){
                hasImg = false;
                break;
            }
        }

        for(var i in obj){
            var c = obj[i];
//            console.log("reply count:"+ c.replyCount);
            if(c.hasImg === 1 && menu_view.currentIndex === 0 && news_main.pageIndex === 0){
                news_main.imgSource = c.imgsrc;
                news_main.imgDocid = c.docid;
                news_main.imgContent = c.title;
            }else{
//            console.log("reply count:"+ c.replyCount);
            listModel.append({
                                 "articleId":c.docid,
                                 "content":c.digest,
                                 "img": hasImg ? c.imgsrc : "",
                                 "title":c.title,
                                 "itemType": 0,
                                 "itemReply": c.replyCount
                             });
            }
        }

    }


    function nextPage(){
        loading.open();
        if(menu_view.currentIndex === 0){// 头条ID
            Common.getStringByUrl("GET","http://c.3g.163.com/nokia/nc/article/headline/"+news_main.currentTid+"/"+news_main.pageIndex+"-"+news_main.pageSize+".html", newsCallback);
        news_list.header = listHeader;
        }else{
            Common.getStringByUrl("GET", "http://c.3g.163.com/nokia/nc/article/list/"+news_main.currentTid+"/"+news_main.pageIndex+"-"+news_main.pageSize+".html", newsCallback);
        }
//        Common.getStringByUrl("GET", "http://c.3g.163.com/nokia/nc/topicset/default.html", newsCallback);
    }
}
