import QtQuick 1.1
import com.nokia.meego 1.0
import "Const.js" as Const
import "Common.js" as Common
import "RunMemory.js" as MemoryUtil

Page {
    id: photo_main
    property int pageSize: 10
    property int pageIndex: 0

    property bool btn_enabled: true
    orientationLock: PageOrientation.LockPortrait

    onStatusChanged: {
        //        if(PageStatus.Active === photo_main.status){
        //            // relashed page
        //            if(MemoryUtil.reflashable === true && MemoryUtil.reflashPage === "photos"){
        //                pic_model.clear();
        //                loading.open();
        //                getPics();
        //            }
        //            MemoryUtil.reflashPage = "";
        //            MemoryUtil.reflashable = false;
        //        }
    }

    TopBackGround{
        id: top_bar
        anchors{left: parent.left; top: parent.top}
        name: "图片"

        onClicked: {
            console.log("go to top");
            pic_view.positionViewAtBeginning();
        }

        ReloadButton{
            id: reload_rect
            width: parent.height; height: parent.height
            anchors{left: parent.left; top: parent.top}

            onClicked: {
                pic_model.clear();
                loading.open();
                photo_main.pageIndex = 0;
                getPics();
            }
        }
        Rectangle{
            id: setting_rect
            width: parent.height; height: parent.height
            color: Const.Color.rectTrans
            anchors{right: parent.right; top: parent.top}

            Item{
                id: setting_btn
                width: 55; height: 55
                anchors.centerIn: parent
                Image{
                    source: "images/setting.png"
                    anchors.fill: parent
                }
            }
            MouseArea{
                anchors.fill: parent
                onClicked: {
                    mainPage.pageStack.push(Qt.resolvedUrl("InfoMainPage.qml"),{reflashPage: "photos"});
                }
            }
        }

    }

    Rectangle{
        id: pic_rect
        //        color: Const.Color.backgroup
        width: parent.width; height: parent.height - top_bar.height
        anchors{left: parent.left; top: top_bar.bottom}
        gradient: Gradient {
            GradientStop { position: 0.0; color: Const.Color.backgroundTop }
            GradientStop { position: 1; color: Const.Color.backgroundBottom }
        }

        ReloadBackground{
            id: reload_back
            anchors.fill: parent
            visible: false
        }

        GridView{
            id: pic_view
            width: parent.width - 10; height: parent.height - 30
            anchors.centerIn: parent
            cellWidth: pic_view.width / 2; cellHeight: pic_view.cellWidth + 50

            model: pic_model
            delegate: picDelegate
            footer: list_footer
        }

        ScrollDecorator{
            flickableItem: pic_view
            platformStyle: ScrollDecoratorStyle{inverted: false}
        }
    }


    Component{
        id: list_footer
        Item{
            width: photo_main.width; height: 80
            Rectangle{
                width: parent.width * 3 / 4; height: parent.height - 20
                anchors.centerIn: parent
                color: Const.Color.rectTrans
                Row{
                    anchors.fill: parent
                    Image{
                        id: left_img
                        width: 7; height: parent.height
                        source: "images/button1_left.png"
                    }

                    Image {
                        id: middle_img
                        width: parent.width - left_img.width - right_img.width; height: parent.height
                        source: "images/button1_mid.png"

                    }
                    Image{
                        id: right_img
                        width: 7; height: parent.height
                        source: "images/button1_right.png"
                    }
                }

                Text{
                    color: "#464646"
                    font{pointSize: Const.FontSize.menuSize}
                    width: parent.width - 20; height: parent.height - 20
                    anchors.centerIn: parent
                    horizontalAlignment: Text.AlignHCenter
                    verticalAlignment: Text.AlignVCenter

                    text: "查看下"+photo_main.pageSize+"条"
                }

                PressArea{
                    id: nextPage_btn
                    anchors.fill: parent
                    enabled: photo_main.btn_enabled
                    pressRadius: 10
                    onClicked: {
                        photo_main.btn_enabled = false;
                        photo_main.nextPage();
                    }
                }
            }
        }
    }

    ListModel{
        id: pic_model
    }

    Component{
        id: picDelegate

        Item{
            width: pic_view.cellWidth; height: pic_view.cellHeight
            Item{
                id: img_back
                //            color: Const.Color.rectTrans
                width: parent.width - 20 ; height: parent.width - 20;
                anchors{horizontalCenter: parent.horizontalCenter; top: parent.top; topMargin: 20}
                Image{
                    anchors.fill: parent
                    source: "images/imageset_list_itemback.png"
                }

                Rectangle{
                    id: img_path
                    anchors.centerIn: parent
                    width: parent.width * 7 / 8; height: parent.height * 7 / 8
                    color: Const.Color.rectTrans

                    Image{
                        anchors.fill: parent
                        source: img
                    }
                }
            }

            Item{
                id: img_title
                //            color: Const.Color.rectTrans
                anchors{horizontalCenter: parent.horizontalCenter; bottom: parent.bottom}
                width: parent.width; height: 50

                Text{
                    anchors.centerIn: parent
                    font{pointSize: 16}
                    color: "#2C2C2C"
                    text: picTitle
                    width: parent.width - 20; height: parent.height - 10
                    horizontalAlignment: Text.AlignLeft
                    verticalAlignment: Text.AlignVCenter

                    wrapMode: Text.WordWrap
                }
            }

            PressArea{
                anchors.fill: parent

                onClicked: {
                    console.log("jump to single image");
                    mainPage.pageStack.push(Qt.resolvedUrl("PicturePage.qml"),{docId:picId, picSetImg:img});
                }
            }

        }
    }

    BusyLoading{
        id: loading
        anchors.centerIn: parent
    }

    Component.onCompleted:{
        loading.open();
        getPics();
    }

    function nextPage(){
        loading.open();
        getPics();
    }

    function getPics(){
        reload_back.visible = true;
        Common.getStringByUrl("GET","http://c.3g.163.com/photo/api/list/0096/4GJ60096/"+(photo_main.pageIndex + photo_main.pageSize)+".json", picCallback)
    }

    function picCallback(responseText){
        var obj = JSON.parse(responseText);
        console.debug("photo_main.pageIndex:"+photo_main.pageIndex);
        for(var i in obj){
            var pics = obj[i];
            if(i >= photo_main.pageIndex){
                pic_model.append({
                                     "picTitle": pics.setname,
                                     "img": pics.clientcover,
                                     "picId": pics.setid

                                 });
            }
        }
        photo_main.pageIndex = photo_main.pageIndex + photo_main.pageSize;
        reload_back.visible = false;
        photo_main.btn_enabled = true;
        loading.close();
    }

}
