import QtQuick 1.1
import com.nokia.meego 1.0
import "Component"
import "Const.js" as Const
import "Common.js" as Common
import "Database.js" as DBUtil

Page {
    id: pic_page

    orientationLock: PageOrientation.LockPortrait
    property int toolsStatus: Const.Status.Closed
    tools: toolbar

    property string picSetName
    property string picSetImg

    ImageToolbar{
        id: toolbar

        isFavorited: pic_page.isFavorite
        favoriteEnable: false
        downloadEnable: false
        onReplyed: {
            reply_comment.open();
        }

        onDownloaded: {
            imageDownload.download(img_view);
            infoShow.open("图片已经成功下载到相册");

        }

        onFavorited: {
            if(pic_page.isFavorite){
                fav_dialog.open("您确定要取消该收藏吗?")
            }else{
                DBUtil.addPictureFavorite(pic_page.docId, pic_page.picSetName, pic_page.picSetImg);
                pic_page.isFavorite = true;
                infoShow.open("图片收藏成功");
            }
        }
    }

    ConfirmDialog{
        id: fav_dialog
        onAccepted: {
            DBUtil.removeSingleFavorite(pic_page.docId, Const.FavorateType.Pictrue);
            pic_page.isFavorite = false;
            infoShow("图片收藏已经取消");
        }
    }

    property string docId

    property string replyBoard
    property int replyCount: 0
    property int totalSize: 0
    property int currentIndex: 0
    property string postId

    property int infoStatus: 1

    property int flickX: 0

    property bool isFavorite: DBUtil.isFavoriteExists(pic_page.docId, Const.FavorateType.Pictrue);

    TopBackGround{
        id: top_bar
        anchors{left: parent.left; top: parent.top}
        name: "图片"
        //        background: "images/imageset_navbar_back.png"
        //        borderColor: "#828282"

        BackButton{
            width: parent.height; height: parent.height
            anchors{left: parent.left; top: parent.top}
        }

        Rectangle{
            width: 120; height: parent.height
            color: Const.Color.rectTrans
            anchors{right: parent.right}

            Rectangle{
                width: 120; height: parent.height
                color: Const.Color.rectTrans
                anchors{right: parent.right}

                CommentButton{
                    width: 110; height: 55
                    anchors.centerIn: parent

                    name: pic_page.replyCount + "跟帖"
                    //                    textBold: false

                    onClicked: {
                        console.log("jump to comment page"+picSetName);
                        pageStack.replace(Qt.resolvedUrl("CommentPage.qml"),{
                                              picIndex: pic_page.currentIndex,
                                              docId:pic_page.postId,
                                              replyBoard:pic_page.replyBoard,
                                              setId:pic_page.docId,
                                              title:picSetName,
                                              backType: Const.FavorateType.Pictrue,
                                              commentType: Const.Comment.Today});
                    }
                }
            }
        }
    }

    Timer {
        id: timeWait
        interval: 1000
        running: false
        repeat: false
        onTriggered: {
            loading.close();
        }
    }

    Rectangle{
        id: image_rect
        color: Const.Color.imageBack
        width: parent.width; height: parent.height - top_bar.height
        anchors{left: parent.left; top: top_bar.bottom}


        Text{
            id: img_pager
            width: parent.width; height: 70
            anchors{horizontalCenter: parent.horizontalCenter; top: parent.top}
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            color: "white"
            font{pointSize: 19}
        }

        ImageLoadBackground{
            id: img_back
            width: parent.width; height: parent.width * 10 / 15
            anchors{horizontalCenter: parent.horizontalCenter; top: img_pager.bottom}
            Image{
                id: img_view
                width: parent.width
                onStatusChanged: {
                    toolbar.downloadEnable = false;
                    console.debug("status changed:"+img_view.status);
                    timeWait.running = false;
                    if (img_view.status == Image.Ready){
                        toolbar.downloadEnable = true;
                        loading.close();
                    }
                }
                fillMode: Image.PreserveAspectFit
            }
            z : 10
        }


        Item{
            id: img_flick
            anchors.fill: img_back
            z: 10

            Flickable{
                anchors.fill: parent
                flickableDirection: Flickable.HorizontalFlick
                contentWidth: parent.width
                contentHeight: parent.height
                pressDelay: 200

                onFlickStarted: {
                    console.debug("flick start x:"+contentX)
                    pic_page.flickX = contentX;
                }

                onFlickEnded: {
                    console.debug("flick end x:"+contentX)
                    if(pic_page.flickX < contentX){
                        console.debug("flick left to right");
                        if(pic_page.currentIndex > 0){
                            timeWait.running = true;
                            openImage(pic_page.currentIndex - 1);
                        }else{
                            infoShow.open("当前已经是第一张图片");
                        }
                    }else{
                        console.debug("flick left to right");
                        if(pic_page.currentIndex < (pic_page.totalSize - 1)){
                            timeWait.running = true;
                            openImage(pic_page.currentIndex + 1);
                        }else{
                            infoShow.open("当前已经是最后一张图片");
                        }
                    }
                    pic_page.flickX = contentX;
                }
            }
        }


        Rectangle{
            id: title_rect
            width: parent.width; height: 70
            color: Const.Color.imageBack
            anchors{horizontalCenter: parent.horizontalCenter; top: img_flick.bottom}
            z: 10
            Text{
                id: info_title
                width: parent.width - 20
                height: 70
                anchors.centerIn: parent

                font{pointSize: 19}
                color: "white"

                horizontalAlignment: Text.AlignVCenter
                verticalAlignment: Text.AlignVCenter

                elide: Text.ElideRight
            }
        }

        Item{
            anchors{horizontalCenter: parent.horizontalCenter; top: title_rect.bottom; topMargin: 10}

            width: parent.width - 20; height: parent.height - 140 - img_flick.height
            Flickable{
                anchors.fill: parent
                flickableDirection: Flickable.VerticalFlick
                contentWidth: Math.max(parent.width,info_content.width)
                contentHeight: Math.max(parent.height,info_content.height)
                pressDelay: 200
                Text{
                    id: info_content
                    width: info_title.width - 40
                    color: "#939393"
                    anchors.horizontalCenter: parent.horizontalCenter
                    font{pointSize: 16}

                    wrapMode: Text.Wrap
                    textFormat: Text.RichText
                }
            }
        }
    }


    ListModel{
        id: pic_model
    }

    BusyLoading{
        id: loading
        anchors.centerIn: parent
    }

    InfoShow{
        id: infoShow
        anchors{bottom: parent.bottom; bottomMargin: 70}
    }

    ReplyToolbar{
        id: reply_comment

        anchors.fill: parent

        onSumbited: {
            console.debug("reply submit");
            replyComment();
        }

        onClosed: {
            toolbar.showImg();
        }

        visible: pic_page.toolsStatus === Const.Status.Opened
    }

    ImageDownload{
        id: imageDownload
    }

    HostInfo{
        id: hostinfo
    }

    Component.onCompleted: {
        loading.open();
        loadImage();
    }

    function getReplyCount(){
        Common.getStringByUrl("GET", "http://comment.api.163.com/api/json/thread/total/"+pic_page.replyBoard+"/"+pic_page.postId, replyCallback);
    }

    function replyCallback(responseText){
        var obj = JSON.parse(responseText);
        pic_page.replyCount = obj.ptcount;
    }

    function loadImage(){
        Common.getStringByUrl("GET", "http://c.3g.163.com/photo/api/set/0096/"+pic_page.docId+".json", picCallback);
    }

    function picCallback(responseText){
        var obj = JSON.parse(responseText);
        pic_page.replyBoard = obj.boardid;
        pic_page.totalSize = obj.imgsum;
        pic_page.postId = obj.postid;
        pic_page.picSetName = obj.setname;
        var photos = obj.photos;
        for(var i in photos){
            var p = photos[i];
            pic_model.append({
                                 "title":p.imgtitle,
                                 "info":p.note,
                                 "img": p.imgurl
                             });
        }
        toolbar.favoriteEnable = true;
        getReplyCount();
        openImage(pic_page.currentIndex);

    }

    function openImage(index){
        loading.open();
        var pic = pic_model.get(index);
        info_content.text = pic.info;
        info_title.text = pic.title;
        img_pager.text = (index + 1) + "/" + pic_page.totalSize;
        img_view.source = Common.getImg(pic.img, img_back.height, img_back.width);
        pic_page.currentIndex = index;
    }

    function changeInfo(){
        if(pic_page.infoStatus === Const.Status.Closed){
            info_content.visible = true;
            image_info.height = info_rect.height + info_line.height + info_content.height + 30;
            pic_page.infoStatus = Const.Status.Opened
        }else{
            info_content.visible = false;
            image_info.height = info_rect.height + info_line.height;
            pic_page.infoStatus = Const.Status.Closed
        }
    }


    function replyComment(){
        var account = DBUtil.getAccount();
        console.debug("account:"+account.username);
        if(account.username === undefined || account.username === "" || account.username === 'undefined'){
            infoShow.open("登录后才能跟贴");
            reply_comment.open();
            return;
        }
        if(reply_comment.text === ""){
            infoShow.open("请填写跟帖内容");
            reply_comment.open();
            return;
        }
        var params = "board="+pic_page.replyBoard+"&threadid="+pic_page.postId+"&body="+reply_comment.text+"&userid="+account.username+"&nickname="+account.nickname+"&ip="+hostinfo.getLocalIp()+"&hidename=false";
        console.debug("params:"+params);
        loading.open();
        var doc = new XMLHttpRequest();
        doc.onreadystatechange = function() {
                    if ((doc.readyState == 4) && (doc.status == 200)) {
                        console.debug(doc.responseText);
                        var obj = JSON.parse(doc.responseText);
                        if(obj.code === '1'){
                            loading.close();
                            reply_comment.close();
                            toolbar.showImg();
                            infoShow.open("您的帖子已经成功提交");
                            getReplyCount();
                        }else{
                            reply_comment.open();
                            loading.close();
                            if(obj.code === '-1'){
                                infoShow.open("参数为null");
                            }else if(obj.code === "-2"){
                                infoShow.open("版面不存在");
                            }else if(obj.code === "-3"){
                                infoShow.open("ThreadData数据错误");
                            }else if(obj.code === "-4"){
                                infoShow.open("PostData数据错误");
                            }else if(obj.code === "-5"){
                                infoShow.open("发贴间隔太短");
                            }else if(obj.code === "-6"){
                                infoShow.open("跟贴大楼封顶");
                            }else if(obj.code === "-7"){
                                infoShow.open("异步存储到跟贴个人页错误");
                            }else{
                                infoShow.open("跟帖失败");
                            }
                        }
                    }
                }
        doc.open("POST", "http://comment.api.163.com/api/jsonp/post/insert", true);
        doc.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
        doc.send(params);
    }

}
