import QtQuick 1.1
import com.nokia.meego 1.0
import "Const.js" as Const
import "Common.js" as Common
import "RunMemory.js" as MemoryUtil
import "Database.js" as DBUtil

Page {
    id: topic_main
    orientationLock: PageOrientation.LockPortrait

    property string imgSource
    property string imgContent
    property string imgDocid
    property int imgReplyCount
    property int imgType: 0

    property int pageIndex: 0
    property int pageSize: 10

    property bool btn_enabled: true

    TopBackGround{
        id: top_bar
        anchors{left: parent.left; top: parent.top}
        name: "话题"

        onClicked: {
            console.log("go to top");
            news_list.positionViewAtBeginning();
        }


        ReloadButton{
            id: reload_rect
            width: parent.height; height: parent.height
            anchors{left: parent.left; top: parent.top}

            onClicked: {
                listModel.clear();
                getTopics();
            }
        }

        Rectangle{
            id: setting_rect
            width: parent.height; height: parent.height
            color: Const.Color.rectTrans
            anchors{right: parent.right; top: parent.top}

            Item{
                id: setting_btn
                width: 55; height: 55
                anchors.centerIn: parent
                Image{
                    source: "images/setting.png"
                    anchors.fill: parent
                }
            }
            MouseArea{
                anchors.fill: parent

                onClicked: {
                    mainPage.pageStack.push(Qt.resolvedUrl("InfoMainPage.qml"),{reflashPage: "topics"});
                }
            }
        }

    }

    Rectangle{
        id: news_content
        anchors{top: top_bar.bottom; left: parent.left}
        width: parent.width; height: parent.height - top_bar.height
//        color: Const.Color.background
        gradient: Gradient {
            GradientStop { position: 0.0; color: Const.Color.backgroundTop }
            GradientStop { position: 1; color: Const.Color.backgroundBottom }
        }

        ReloadBackground{
            id: reload_back
            anchors.fill: parent
            visible: false
        }

        ListView{
            id: news_list
            anchors.fill: parent

            model: listModel
            delegate: listDelegate


        }
    }

    ListModel{
        id: listModel

    }

    Component{
        id: listHeader

        Item{
            width: topic_main.width; height: 255
        Rectangle{
            anchors.fill: parent
            color: Const.Color.rectTrans
            ImageLoadBackground{
                width: parent.width; height: parent.height
                Image{
                    anchors.fill: parent
                    source: topic_main.imgSource
                }

                Item{
                    width: parent.width; height: 45
                    anchors.left: parent.left; anchors.bottom: parent.bottom

                    Rectangle{
                        color: "black"
                        opacity: 0.5
                        anchors.fill: parent
                        border{color: "#828282"; width: 1}
                    }

                    Text{
                        font{pointSize: Const.FontSize.menuSize}
                        color: "white"
                        anchors.centerIn: parent

                        width: parent.width - 20; height: parent.height - 20
                        horizontalAlignment: Text.AlignLeft
                        verticalAlignment: Text.AlignVCenter

                        text: topic_main.imgContent
                    }
                }
            }

            PressArea{
                id: header_area
                anchors.fill: parent

                onClicked: {
                    mainPage.pageStack.push(Qt.resolvedUrl("TopicPage.qml"),{docId: topic_main.imgDocid, pageIndex: 1});
                }
            }

        }
                }

    }


    Component{
        id: listFooter
        Item{
            width: topic_main.width; height: 80
            Rectangle{
                width: parent.width * 3 / 4; height: parent.height - 20
                anchors.centerIn: parent
                color: Const.Color.rectTrans
        Row{
            anchors.fill: parent
            Image{
                id: left_img
                width: 7; height: parent.height
                source: "images/button1_left.png"
            }

            Image {
                id: middle_img
                width: parent.width - left_img.width - right_img.width; height: parent.height
                source: "images/button1_mid.png"

            }
            Image{
                id: right_img
                width: 7; height: parent.height
                source: "images/button1_right.png"
            }
        }

                Text{
                    color: "#464646"
                    font{pointSize: Const.FontSize.menuSize}
                    width: parent.width - 20; height: parent.height - 10
                    anchors.centerIn: parent

                    horizontalAlignment: Text.AlignHCenter
                    verticalAlignment: Text.AlignVCenter

                    text: "查看下"+topic_main.pageSize+"条"
                }

                PressArea{
                    id: nextPage_btn
                    anchors.fill: parent
                    enabled: topic_main.btn_enabled
                    pressRadius: 10
                    onClicked: {
                        topic_main.btn_enabled = false;
                        topic_main.nextPage();
                    }
                }
            }
        }
    }

    BusyLoading{
        id: loading
        anchors.centerIn: parent
    }

    Component{
        id: listDelegate

        Item{
//            gradient: Gradient {
//                GradientStop { position: 0.0; color: "#EAEAEB" }
//                GradientStop { position: 0.1; color: "#EDEDEE" }
//                GradientStop { position: 1; color: "#EDEDEE" }
//            }
//            border{color: "#DDDDDD"; width: 1}

            width: topic_main.width; height: 100

            Rectangle{
                width: parent.width - view_detail.width; height: parent.height
                color: Const.Color.rectTrans
                anchors{left: parent.left; top: parent.top}
                Item{
                    id: img_cell
                    width: 30; height: parent.height
                    anchors{left: parent.left; top: parent.top}
                    Image{
                        id: img_unread
                        anchors{horizontalCenter: parent.horizontalCenter; top: parent.top; topMargin: 20}
                        source: isReaded ? "images/cell_left_unread_highlight.png" : "images/cell_left_unread.png"
                        width: 21; height: 21
                    }
                }

                Item{

                    width: parent.width - img_cell.width - 20; height: parent.height - 20
                    anchors{left: img_cell.right; leftMargin: 10; top: parent.top; topMargin: 10}

                    Item{
                        id: row_1
                        width: parent.width; height: 40
                        anchors{left: parent.left; top: parent.top}

                        Text{
                            id: topic_title
                            color: Const.Color.listTitle
                            font{pointSize: 19; bold: true}
                            text: title
                            anchors.fill: parent

                            horizontalAlignment: Text.AlignLeft
                            verticalAlignment: Text.AlignVCenter

                            elide: Text.ElideRight

                        }
                    }

                    Item{
                        width: parent.width; height: 40
                        anchors{left: row_1.left; top: row_1.bottom; topMargin: 5}
                        Text{
                            id: topic_type
                            color: Const.Color.listWord
                            height: parent.height
                            font{pointSize: 16}
                            anchors{left: parent.left; verticalCenter:  parent.verticalCenter}

                            horizontalAlignment: Text.AlignLeft
                            verticalAlignment: Text.AlignVCenter

                            text: subtitle
                        }

                        Text{
                            id: topic_date
                            color: Const.Color.listWord
                            height: parent.height
                            font{pointSize: 16}
                            anchors{right: parent.right; verticalCenter:  parent.verticalCenter}

                            horizontalAlignment: Text.AlignLeft
                            verticalAlignment: Text.AlignVCenter

                            text: date
                        }
                    }

                }
            }

            Item{
                id: view_detail
                width: 30; height: parent.height
                anchors{right: parent.right; top: parent.top}
                Image {
                    id: view_img
                    source: "images/cell_right_arraw.png"
                    anchors{left: parent.left; verticalCenter: parent.verticalCenter}
                }
            }

            Image {
                id: line
                source: "images/line.png"
                width: parent.width
                anchors.bottom: parent.bottom
                anchors.left: parent.left
            }

            PressArea{
                anchors.fill: parent

                onClicked: {
                    img_unread.source = "images/cell_left_unread_highlight.png";
                    topic_title.color = Const.Color.listWord;
                    DBUtil.addReadStatus(Const.ReadStatus.Topic, topicId);
                    MemoryUtil.addTopicRead(topicId);
                    mainPage.pageStack.push(Qt.resolvedUrl("TopicPage.qml"),{docId:topicId, pageIndex: index + 1});

                }
            }
        }

    }

    Component.onCompleted: {
        console.log("topic_main completed");
        loading.open();
        getTopics();
    }

    onStatusChanged: {
        if(PageStatus.Active === topic_main.status){
            // relashed page
//            if(MemoryUtil.reflashable === true && MemoryUtil.reflashPage === "topics"){
//                listModel.clear();
//                getTopics();
//            }
//            MemoryUtil.reflashPage = "";
//            MemoryUtil.reflashable = false;
        }
    }

    function getTopics(){
        console.log("get topics");
        loading.open();
        reload_back.visible = true;
        news_list.header = null;
        news_list.footer = null;
        Common.getStringByUrl("GET", "http://c.3g.163.com/nokia/nc/article/attitude/"+topic_main.pageIndex+"-"+topic_main.pageSize+".html", topicsCallback);
    }

    function topicsCallback(responseText){
        console.log(responseText);
        var obj = JSON.parse(responseText);
        var topics = obj.attitude;
        news_list.header = listHeader;
        news_list.footer = listFooter;
        for(var i in topics){
            var topic = topics[i];
            if(topic_main.pageIndex === 0 && topic.hasImg === 1){
                topic_main.imgContent = topic.title;
                topic_main.imgDocid = topic.docid;
                topic_main.imgSource = topic.imgsrc;
            }else{

            listModel.append({
                                 "isReaded": MemoryUtil.isTopicReaded(topic.docid),
                                 "topicId":topic.docid,
                                 "title":topic.title,
                                 "itemReply":topic.replyCount,
                                 "subtitle":topic.subtitle,
                                 "date":Common.getDate(topic.ptime)
                             });
            }
        }
        topic_main.pageIndex += topic_main.pageSize;

        reload_back.visible = false;
        topic_main.btn_enabled = true;
        loading.close();
    }

    function nextPage(){
        loading.open();
        Common.getStringByUrl("GET", "http://c.3g.163.com/nokia/nc/article/attitude/"+topic_main.pageIndex+"-"+topic_main.pageSize+".html", topicsCallback);
    }
}

