import QtQuick 1.1
import com.nokia.meego 1.0
import "Const.js" as Const
import "Common.js" as Common

Item {
    id: root

    property int total: 0
    property string itemId
    property string voteId
    property alias model: item_repear.model
    property alias buttonModel: item_button.model
    property string itemQue

    signal voted

    z: 50
    visible: false
    Rectangle{
        color: "black"
        anchors.fill: parent
        opacity: 0.5
    }

    Rectangle{
        color: "#EBE9E9"
        border{color: "#939390"; width: 1}
        width: parent.width - 40; height: vote_title.height + vote_info.height + vote_com.height + voteItem.height + vote_btn.height
        anchors.centerIn: parent

        Item{
            id: vote_title
            width: parent.width - 30; height: 60
            anchors{horizontalCenter: parent.horizontalCenter; top: parent.top}

            Image{
                id: title_img
                anchors{left: parent.left; verticalCenter: parent.verticalCenter}
                source: "images/vote_title.png"
                width: 18; height: 18
            }

            Text{
                width: parent.width - title_img.width - 20; height: parent.height
                anchors{left: title_img.right; leftMargin: 20; verticalCenter: parent.verticalCenter}
                color: Const.Color.listTitle
                font{pointSize: 16}

                text: "投票问题"

                horizontalAlignment: Text.AlignLeft
                verticalAlignment: Text.AlignVCenter
            }
        }

        Item{
            id: vote_info
            width: parent.width - 30; height: 60;
            anchors{horizontalCenter: parent.horizontalCenter; top: vote_title.bottom}
            Text{
                width: parent.width; height: parent.height - 20
                anchors.centerIn: parent
                color: Const.Color.listTitle
                font{pointSize: 17}

                horizontalAlignment: Text.AlignLeft

                wrapMode: Text.WordWrap

                text: root.itemQue
            }

        }

        Item{
            id: vote_com
            anchors{top: vote_info.bottom; horizontalCenter: parent.horizontalCenter}
            width: parent.width - 30; height: 45
            Text{
                id: vote_status
                anchors{left: parent.left; verticalCenter: parent.verticalCenter}
                color: "#878787"
                font{pointSize: 14}
                text: "您的态度"

                horizontalAlignment: Text.AlignLeft
                verticalAlignment: Text.AlignVCenter
            }
            Text{
                anchors{right: vote_date.left; verticalCenter: parent.verticalCenter}
                color: "#878787"
                font{pointSize: 14}

                horizontalAlignment: Text.AlignRight
                verticalAlignment: Text.AlignVCenter

                text: "已有投票:"
            }

            Text{
                id: vote_date
                anchors{right: parent.right; verticalCenter: parent.verticalCenter}
                color: "#C37090"
                font{pointSize: 14}

                horizontalAlignment: Text.AlignRight
                verticalAlignment: Text.AlignVCenter

                text: root.total
            }
        }

        Item{
            id: voteItem
            width: parent.width - 30; height: item_repear.model.count * 60
            anchors{horizontalCenter: parent.horizontalCenter; top: vote_com.bottom}
            Column{
                id: listview

                Repeater{
                    id: item_repear
                    delegate: Item{
                        width: voteItem.width; height: 60
                        Text{
                            id: item_name
                            color: Const.Color.listTitle
                            font{pointSize: 16}
                            width: parent.width; height: 45
                            anchors{left: parent.left; verticalCenter: parent.verticalCenter}

                            horizontalAlignment: Text.AlignLeft
                            verticalAlignment: Text.AlignVCenter

                            text: (index+1) + "." + itemName
                        }

                    }
                }

            }
        }


        Item{
            id: voteButton
            width: 60; height: item_button.model.count * 60
            anchors{right: parent.right; rightMargin: 15; top: vote_com.bottom}
            ButtonColumn{
                id: listButton
                width: parent.width; height: parent.height
                anchors{right: parent.right; top: parent.top; topMargin: 10}
                Repeater{
                    id: item_button
                    delegate: RadioButton{
                            platformStyle: RadioButtonStyle {
                                inverted: false
                            }
                            width: 60;height: 60
                            checked: index === 0
                            onClicked: {
                                console.debug("id:"+itemId+"; num:"+itemNum);
                                root.itemId = itemId;
                            }

                            Component.onCompleted: {
                                if(index === 0){
                                    root.itemId = itemId;
                                }
                            }
                        }


                    }


            }
        }

        Item{
            id: vote_btn
            width: parent.width - 30; height: 80
            anchors{horizontalCenter: parent.horizontalCenter; top: voteItem.bottom}

            Rectangle{
                    color: Const.Color.rectTrans
        Row{
            anchors.fill: parent
            Image{
                id: left_img
                width: 7; height: parent.height
                source: "images/button1_left.png"
            }

            Image {
                id: middle_img
                width: parent.width - left_img.width - right_img.width; height: parent.height
                source: "images/button1_mid.png"

            }
            Image{
                id: right_img
                width: 7; height: parent.height
                source: "images/button1_right.png"
            }
        }
                    width: parent.width / 3; height: parent.height - 30
                    anchors{left: parent.left; leftMargin: parent.width / 12; verticalCenter: parent.verticalCenter}

                    Text{
                        anchors.fill: parent
                        color: Const.Color.article
                        font{pointSize: 20}
                        anchors.centerIn: parent
                        text: "投票"

                        horizontalAlignment: Text.AlignHCenter
                        verticalAlignment: Text.AlignVCenter
                    }

                    PressArea{
                        anchors.fill: parent
                        pressRadius: 10
                        onClicked: {
                            console.debug("vote btn on");
                            vote();
                        }
                    }
                }

            Rectangle{
                    color: Const.Color.rectTrans
        Row{
            anchors.fill: parent
            Image{
                id: left1_img
                width: 7; height: parent.height
                source: "images/button1_left.png"
            }

            Image {
                id: middle1_img
                width: parent.width - left1_img.width - right1_img.width; height: parent.height
                source: "images/button1_mid.png"

            }
            Image{
                id: right1_img
                width: 7; height: parent.height
                source: "images/button1_right.png"
            }
        }
                    width: parent.width / 3; height: parent.height - 30
                    anchors{right: parent.right; rightMargin: parent.width / 12; verticalCenter: parent.verticalCenter}

                    Text{
                        anchors.fill: parent
                        color: Const.Color.article
                        font{pointSize: 20}
                        text: "关闭"
                        anchors.centerIn: parent

                        horizontalAlignment: Text.AlignHCenter
                        verticalAlignment: Text.AlignVCenter
                    }

                    PressArea{
                        anchors.fill: parent
                        pressRadius: 10
                        onClicked: {
                            console.debug("vote page close");
                            close();
                        }
                    }
                }

            }
        }

    InfoShow{
        id: infoShow
        anchors{bottom: parent.bottom; bottomMargin: 50}
    }

    function open(){
        root.itemId = "";
        root.visible = true;
    }

    function close(){
        root.visible = false;

    }

    function vote(){
        if(root.itemId === ""){
            infoShow.open("您没有选择任何选项!");
        }else{
            Common.getStringByUrl("POST", "http://vote.3g.163.com/vote2/mobileVote.do?vote"+root.voteId+"="+root.itemId+"&voteId="+root.voteId, voteCallback);

        }

    }

    function voteCallback(responseText){
        var obj = JSON.parse(responseText);
        if(obj.result === "success"){
            close();
            root.voted();
        }else{
            infoShow.open("投票失败");
        }
    }
}
