import QtQuick 1.0
import com.nokia.meego 1.0
import "Const.js" as Const
import "Common.js" as Common
import "Component"
import "RunMemory.js" as MemoryUtil

Item {
    id: root

    property int total: 0
    property string itemId
    property string voteId
    property alias model: item_repear.model
    property string note
    property string itemQue

    signal voted

    z: 50
    visible: false

    Rectangle{
        color: "black"
        anchors.fill: parent
        opacity: 0.5
    }

    Rectangle{
        color: "#EBE9E9"
        border{color: "#939390"; width: 1}
        width: parent.width - 40; height: vote_title.height + vote_info.height + vote_com.height + voteItem.height + vote_btn.height
        anchors.centerIn: parent

        Item{
            id: vote_title
            width: parent.width - 30; height: 60
            anchors{horizontalCenter: parent.horizontalCenter; top: parent.top}

            Image{
                id: title_img
                anchors{left: parent.left; verticalCenter: parent.verticalCenter}
                source: "images/vote_title.png"
                width: 18; height: 18
            }

            Text{
                width: parent.width - title_img.width - 20; height: parent.height
                anchors{left: title_img.right; leftMargin: 20; verticalCenter: parent.verticalCenter}
                color: Const.Color.listTitle
                font{pointSize: 16}

                text: "投票问题"

                horizontalAlignment: Text.AlignLeft
                verticalAlignment: Text.AlignVCenter
            }
        }

        Item{
            id: vote_info
            width: parent.width - 30; height: 60;
            anchors{horizontalCenter: parent.horizontalCenter; top: vote_title.bottom}
            Text{
                width: parent.width; height: parent.height - 20
                anchors.centerIn: parent
                color: Const.Color.listTitle
                font{pointSize: 17}

                horizontalAlignment: Text.AlignLeft

                wrapMode: Text.WordWrap

                text: root.itemQue
            }

        }

        Item{
            id: vote_com
            anchors{top: vote_info.bottom; horizontalCenter: parent.horizontalCenter}
            width: parent.width - 30; height: 45
            Text{
                id: vote_status
                anchors{left: parent.left; verticalCenter: parent.verticalCenter}
                color: "#878787"
                font{pointSize: 14}
                text: root.note

                horizontalAlignment: Text.AlignLeft
                verticalAlignment: Text.AlignVCenter
            }
            Text{
                anchors{right: vote_date.left; verticalCenter: parent.verticalCenter}
                color: "#878787"
                font{pointSize: 14}

                horizontalAlignment: Text.AlignRight
                verticalAlignment: Text.AlignVCenter

                text: "已有投票:"
            }

            Text{
                id: vote_date
                anchors{right: parent.right; verticalCenter: parent.verticalCenter}
                color: "#C37090"
                font{pointSize: 14}

                horizontalAlignment: Text.AlignRight
                verticalAlignment: Text.AlignVCenter

                text: root.total
            }
        }

        Item{
            id: voteItem
            width: parent.width - 30; height: item_repear.model.count * 80
            anchors{horizontalCenter: parent.horizontalCenter; top: vote_com.bottom}
            Column{
                id: listview

                Repeater{
                    id: item_repear
                    delegate: Item{
                        width: voteItem.width; height: 80
                        Text{
                            id: item_name
                            color: Const.Color.listTitle
                            font{pointSize: 16}
                            width: parent.width; height: 40
                            anchors{left: parent.left; top: parent.top}

                            horizontalAlignment: Text.AlignLeft
                            verticalAlignment: Text.AlignVCenter

                            text: (index+1) + "." + itemName
                        }

                        ProgressBar{
                            id: progress_bar
                            total: root.total
                            current: itemNum
                            color: getColor(index);
                            width: parent.width; height: parent.height - item_name.height
                            anchors{left: parent.left; bottom: parent.bottom}

                            Component.onCompleted: {
                                console.debug("index:"+index+"; count:"+item_repear.model.count);
                                progress_bar.count(itemTNum, itemNum, index === (itemCount - 1));
                            }
                        }

                    }
                }

            }
        }

        Item{
            id: vote_btn
            width: parent.width - 30; height: 80
            anchors{horizontalCenter: parent.horizontalCenter; top: voteItem.bottom}

            Rectangle{
                     color: Const.Color.rectTrans
        Row{
            anchors.fill: parent
            Image{
                id: left_img
                width: 7; height: parent.height
                source: "images/button1_left.png"
            }

            Image {
                id: middle_img
                width: parent.width - left_img.width - right_img.width; height: parent.height
                source: "images/button1_mid.png"

            }
            Image{
                id: right_img
                width: 7; height: parent.height
                source: "images/button1_right.png"
            }
        }
                    width: parent.width / 3; height: parent.height - 30
                    anchors.centerIn: parent

                    Text{
                        anchors.fill: parent
                        color: Const.Color.article
                        font{pointSize: 20}
                        anchors.centerIn: parent
                        text: "关闭"

                        horizontalAlignment: Text.AlignHCenter
                        verticalAlignment: Text.AlignVCenter
                    }

                    PressArea{
                        anchors.fill: parent
                        pressRadius: 10
                        onClicked: {
                            console.debug("vote page close");
                            close();
                        }
                    }
                }

            }
        }

    InfoShow{
        id: infoShow
        anchors{bottom: parent.bottom; bottomMargin: 50}
    }

    Component.onCompleted: {

    }

    function open(desc){
        root.itemId = "";
        root.note = desc;
        root.visible = true;
    }

    function close(){
        root.visible = false;

    }

    function getColor(index){
        if(index === 0){
            return "blue";
        }else if(index === 1){
            return "green";
        }else if(index === 2){
            return "red";
        }else if(index === 3){
            return "orange";
        }else if(index === 4){
            return "brown";
        }else if(index === 5){
            return "purple";
        }else{
            return "#717171";
        }
    }
}
