import QtQuick 1.0
import com.nokia.meego 1.0
import "Const.js" as Const
import "Database.js" as DBUtil
import "RunMemory.js" as MemoryUtil

Item {
    id: root

    property string size

    property int initCheckIndex: -1

    property int currentIndex: -1

    z: 50
    visible: false
    Rectangle{
        color: "black"
        anchors.fill: parent
        opacity: 0.5
    }


    Rectangle{
        color: "#EBE9E9"
        border{color: "#939390"; width: 1}
        width: parent.width - 40; height: vote_title.height +voteItem.height + vote_btn.height
        anchors.centerIn: parent

        Rectangle{
            id: vote_title
            width: parent.width; height: 80
            anchors{horizontalCenter: parent.horizontalCenter; top: parent.top}
            color: "black"

            Text{
                width: parent.width - 50; height: parent.height
                anchors{left: parent.left; verticalCenter: parent.verticalCenter}
                color: Const.Color.listTitle
                font{pointSize: 22}

                text: "文字大小"

                horizontalAlignment: Text.AlignLeft
                verticalAlignment: Text.AlignVCenter
            }
        }

        Item{
            id: voteItem
            width: parent.width - 30; height: item_repear.model.count * 60
            anchors{horizontalCenter: parent.horizontalCenter; top: vote_title.bottom}
            Column{
                id: listview

                Repeater{
                    id: item_repear
                    model: listModel
                    delegate: Item{
                        width: voteItem.width; height: 60
                        Text{
                            id: item_name
                            color: Const.Color.listTitle
                            font{pointSize: 22}
                            width: parent.width; height: 45
                            anchors{left: parent.left; verticalCenter: parent.verticalCenter}

                            horizontalAlignment: Text.AlignLeft
                            verticalAlignment: Text.AlignVCenter

                            text: itemName
                        }

                    }
                }

            }
        }


        Item{
            id: voteButton
            width: 60; height: item_button.model.count * 60
            anchors{right: parent.right; rightMargin: 15; top: vote_title.bottom}
            ButtonColumn{
                id: listButton
                width: parent.width; height: parent.height
                anchors{right: parent.right; top: parent.top; topMargin: 10}
                Repeater{
                    id: item_button
                    model: listModel
                    delegate: RadioButton{
                            platformStyle: RadioButtonStyle {
                                inverted: false
                            }
                            width: 60;height: 60
                            checked: size === MemoryUtil.CurrentSize
                            onClicked: {
                                root.size = size;
                                root.currentIndex = index;
                            }

                            Component.onCompleted: {
                                if(size === MemoryUtil.CurrentSize){
                                    root.initCheckIndex = index;
                                    console.debug("root.initCheckIndex:"+root.initCheckIndex);
                                }
                            }
                        }


                    }


            }
        }

        Item{
            id: vote_btn
            width: parent.width - 30; height: 80
            anchors{horizontalCenter: parent.horizontalCenter; top: voteItem.bottom}

            Rectangle{
                  color: Const.Color.rectTrans
        Row{
            anchors.fill: parent
            Image{
                id: left_img
                width: 7; height: parent.height
                source: "images/button1_left.png"
            }

            Image {
                id: middle_img
                width: parent.width - left_img.width - right_img.width; height: parent.height
                source: "images/button1_mid.png"

            }
            Image{
                id: right_img
                width: 7; height: parent.height
                source: "images/button1_right.png"
            }
        }
                    width: parent.width / 3; height: parent.height - 30
                    anchors{left: parent.left; leftMargin: parent.width / 12; verticalCenter: parent.verticalCenter}

                    Text{
                        anchors.fill: parent
                        color: Const.Color.article
                        font{pointSize: 20}
                        anchors.centerIn: parent
                        text: "确定"

                        horizontalAlignment: Text.AlignHCenter
                        verticalAlignment: Text.AlignVCenter
                    }

                    PressArea{
                        anchors.fill: parent
                        pressRadius: 10

                        onClicked: {
                            saveSetting();
                            root.initCheckIndex = root.currentIndex;
                        }
                    }
                }

            Rectangle{
                 color: Const.Color.rectTrans
        Row{
            anchors.fill: parent
            Image{
                id: left1_img
                width: 7; height: parent.height
                source: "images/button1_left.png"
            }

            Image {
                id: middle1_img
                width: parent.width - left1_img.width - right1_img.width; height: parent.height
                source: "images/button1_mid.png"

            }
            Image{
                id: right1_img
                width: 7; height: parent.height
                source: "images/button1_right.png"
            }
        }
                    width: parent.width / 3; height: parent.height - 30
                    anchors{right: parent.right; rightMargin: parent.width / 12; verticalCenter: parent.verticalCenter}

                    Text{
                        anchors.fill: parent
                        color: Const.Color.article
                        font{pointSize: 20}
                        anchors.centerIn: parent
                        text: "取消"

                        horizontalAlignment: Text.AlignHCenter
                        verticalAlignment: Text.AlignVCenter
                    }

                    PressArea{
                        anchors.fill: parent
                        pressRadius: 10

                        onClicked: {
                            console.debug("vote page close");
                            close();
                        }
                    }
                }

            }
        }

    ListModel{
        id: listModel
        ListElement{size: 22; itemName: "超大"}
        ListElement{size: 20; itemName: "大"}
        ListElement{size: 18; itemName: "中"}
        ListElement{size: 16; itemName: "小"}
    }

    function open(){
        if(root.initCheckIndex > -1){
            item_button.itemAt(root.initCheckIndex).checked = true;
        }
        root.visible = true;
    }

    function close(){
        root.visible = false;
    }

    function saveSetting(){
        DBUtil.updateArticleSize(root.size);
        MemoryUtil.setArticleSize(root.size);
        close();
    }
}
