import QtQuick 1.1
import com.nokia.meego 1.0
import "Database.js" as DBUtil
import "RunMemory.js" as MemoryUtil
import "Const.js" as Const
import "Common.js" as Common

PageStackWindow {
    id: mainWindow


    platformStyle: defaultStyle;

    showStatusBar: true

    PageStackWindowStyle {
        id: defaultStyle
        cornersVisible: false
    }

    Timer {
        id: loadingWait
        interval: 500; running: false; repeat: false
        onTriggered: pageStack.push(Qt.resolvedUrl("MainPage.qml"))
    }


    initialPage: loadingPage

    Loading{id:loadingPage}

    Timer {
        id: connectOuttime
        interval: 10000
        running: false
        repeat: false
        onTriggered: {
            loadingWait.running = true;
        }
    }

    Component.onCompleted: {
        clearReadedInfo();
        initSetting();
        initColumns();

    }

    function clearReadedInfo(){// 清除30天以前的已读信息
        DBUtil.removeReadStatus();
        var artiArray = DBUtil.getReadStatusByType(Const.ReadStatus.Article);
        console.debug("INFO arti length:"+artiArray.length);
        for(var i in artiArray){
            var arti = artiArray[i];
            MemoryUtil.addArticleRead(arti.docid);
        }
        var topicArray = DBUtil.getReadStatusByType(Const.ReadStatus.Topic);
        console.debug("INFO topicArray length:"+topicArray.length);
        for(var k in topicArray){
            var t = topicArray[k];
            MemoryUtil.addTopicRead(t.docid);
        }
    }

    function initColumns(){
        getNewsTopics()

    }

    function getNewsTopics(){
        connectOuttime.running = true;
        Common.getStringByUrl("GET", "http://c.3g.163.com/nokia/nc/topicset/default.html", newsTopicsCallback);

    }

    function newsTopicsCallback(responseText){
        connectOuttime.running = false;
        var cols = DBUtil.getAllColumns();
        console.debug("columns length:"+cols.length);
        var obj = JSON.parse(responseText);
        var columns = obj["default-topicset"];
        for(var i in columns){
            var m =columns[i];
            // 初始
            if(m.tid !== "T1295501906343"){
                if(cols.length === 0 && parseInt(i) > 0 && parseInt(i) < 5){
                    console.debug("update:"+m.tname);
                    DBUtil.updateColumn(m.tid, m.tname, 1);
                }else{
                    console.debug("insert:"+m.tname);
                    DBUtil.insertColumns(m.tid, m.tname);
                }
            }

        }
        loadingWait.running = true;

    }

    function initSetting(){
        var setting = DBUtil.getSetting();
        if(setting !== null){
            MemoryUtil.setPager(setting.pager);
            MemoryUtil.setArticleSize(setting.articleSize);
        }
    }
}
